<?php
/**
 * Elementor class
 *
 * @package RediasCore
 */
namespace RediasCore\Classes;

defined( 'ABSPATH' ) || die();

class Elementor {

    const MINIMUM_ELEMENTOR_VERSION = '3.5.0';

    const MINIMUM_PHP_VERSION = '7.4';

    /**
     * Class constructor
     */
    function __construct() {

        // Check if Elementor installed and activated
        if ( ! did_action( 'elementor/loaded' ) ) {
            add_action( 'admin_notices', [$this, 'admin_notice_missing_elementor'] );
            return;
        }

        // Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
        }
        
        // Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
			return;
        }

        add_action( 'elementor/elements/categories_registered', [ $this, 'categories_register' ] );

        
        add_action( 'init', [$this, 'post_type_support'] );
    }

    /**
     * Admin notice for missing Elementor
     */
    public function admin_notice_missing_elementor() {

        if ( isset( $_GET['activate'] ) ) {
            unset( $_GET['activate'] );
        }

        $notice = sprintf(
            /* translators: 1: Plugin name 2: Elementor 3: Elementor installation link */
            __( '%1$s requires %2$s to be installed and activated to function properly. %3$s', 'redias-core' ),
            '<strong>' . __( 'Redias Core', 'redias-core' ) . '</strong>',
            '<strong>' . __( 'Elementor', 'redias-core' ) . '</strong>',
            '<a href="' . esc_url( admin_url( 'plugin-install.php?s=Elementor&tab=search&type=term' ) ) . '">' . __( 'Please click on this link to install Elementor', 'redias-core' ) . '</a>'
        );
    
        printf( '<div class="notice notice-warning is-dismissible"><p style="padding: 13px 0">%1$s</p></div>', $notice );
    }

    /**
     * Admin notice for minimum Elementor version
     */
    public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'redias-core' ),
			'<strong>' . esc_html__( 'Redias Core', 'redias-core' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'redias-core' ) . '</strong>',
			self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

    }
    
    /**
     * Admin notice for minimum PHP version
     */
    public function admin_notice_minimum_php_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'redias-core' ),
			'<strong>' . esc_html__( 'Redias Core', 'redias-core' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'redias-core' ) . '</strong>',
			self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

    }

    /**
     * Register Category
     *
     * @param [type] $elements_manager
     * @return void
     */
    public function categories_register( $elements_manager ){

        $elements_manager->add_category(
            'redias-core',
            [
                'title' => esc_html__( 'Redias', 'redias-core' ),
                'icon' => 'eicon-parallax',
            ]
        );

    }

    /**
     * Elementor support in post type
     *
     * @return void
     */
    public function post_type_support() {
        $post_types = ['dl-project', 'dl-service'];
        foreach( $post_types as $post_type ) {
            add_post_type_support( $post_type, 'elementor' );
        }
    }

}
