<?php
/**
 * Helper class
 *
 * @package RediasCore
 */
namespace RediasCore\Classes;

defined( 'ABSPATH' ) || die();

class Helper {
    
    /**
     * Get elementor instance
     *
     * @return \Elementor\Plugin
     */
    static function elementor_instance() {
        return \Elementor\Plugin::instance();
    }

    /**
     * Check elementor version
     *
     * @param string $version
     * @param string $operator
     * @return bool
     */
    static function is_elementor_version( $operator = '<', $version = '2.6.0' ) {
        return defined( 'ELEMENTOR_VERSION' ) && version_compare( ELEMENTOR_VERSION, $version, $operator );
    }

    /**
     * Render icon html with backward compatibility
     *
     * @param array $settings
     * @param string $old_icon_id
     * @param string $new_icon_id
     * @param array $attributes
     */
    static function render_icon( $settings = [], $old_icon_id = 'icon', $new_icon_id = 'selected_icon', $attributes = [] ) {
        // Check if its already migrated
        $migrated = isset( $settings['__fa4_migrated'][$new_icon_id] );
        // Check if its a new widget without previously selected icon using the old Icon control
        $is_new = empty( $settings[$old_icon_id] );

        $attributes['aria-hidden'] = 'true';

        if ( self::is_elementor_version( '>=', '2.6.0' ) && ( $is_new || $migrated ) ) {
            \Elementor\Icons_Manager::render_icon( $settings[$new_icon_id], $attributes );
        } else {
            if ( empty( $attributes['class'] ) ) {
                $attributes['class'] = $settings[$old_icon_id];
            } else {
                if ( is_array( $attributes['class'] ) ) {
                    $attributes['class'][] = $settings[$old_icon_id];
                } else {
                    $attributes['class'] .= ' ' . $settings[$old_icon_id];
                }
            }
            printf( '<i %s></i>', \Elementor\Utils::render_html_attributes( $attributes ) );
        }
    }

    /**
     * Get a list of all the allowed html tags.
     *
     * @param string $level Allowed levels are basic and intermediate
     * @return array
     */
    static function get_allowed_html_tags( $level = 'basic' ) {
        $allowed_html = [
            'b'      => [],
            'i'      => [],
            'u'      => [],
            's'      => [],
            'br'     => [],
            'em'     => [],
            'del'    => [],
            'ins'    => [],
            'sub'    => [],
            'sup'    => [],
            'code'   => [],
            'mark'   => [],
            'small'  => [],
            'strike' => [],
            'abbr'   => [
                'title' => [],
            ],
            'span'   => [
                'class' => [],
            ],
            'strong' => [],
        ];

        if ( $level === 'intermediate' ) {
            $tags = [
                'a'       => [
                    'href'  => [],
                    'title' => [],
                    'class' => [],
                    'id'    => [],
                ],
                'i'       => [
                    'class' => [],
                ],
                'q'       => [
                    'cite' => [],
                ],
                'img'     => [
                    'src'    => [],
                    'alt'    => [],
                    'height' => [],
                    'width'  => [],
                ],
                'svg'     => [
                    'class'           => true,
                    'aria-hidden'     => true,
                    'aria-labelledby' => true,
                    'role'            => true,
                    'xmlns'           => true,
                    'width'           => true,
                    'height'          => true,
                    'viewbox'         => true,
                ],
                'g'       => ['fill' => true],
                'title'   => ['title' => true],
                'path'    => [
                    'd'    => true,
                    'fill' => true,
                ],
                'dfn'     => [
                    'title' => [],
                ],
                'time'    => [
                    'datetime' => [],
                ],
                'cite'    => [
                    'title' => [],
                ],
                'acronym' => [
                    'title' => [],
                ],
                'hr'      => [],
            ];

            $allowed_html = array_merge( $allowed_html, $tags );
        }

        return $allowed_html;
    }

    /**
     * Strip all the tags except allowed html tags
     *
     * The name is based on inline editing toolbar name
     *
     * @param string $string
     * @return string
     */
    static function kses_basic( $string = '' ) {
        return wp_kses( $string, self::get_allowed_html_tags( 'basic' ) );
    }

    /**
     * Strip all the tags except allowed html tags
     *
     * The name is based on inline editing toolbar name
     *
     * @param string $string
     * @return string
     */
    static function kses_advance( $string = '' ) {
        return wp_kses( $string, self::get_allowed_html_tags( 'intermediate' ) );
    }

    /**
     * Limit Letter
     *
     * @param [type] $string
     * @param [type] $limit_length
     * @param string $suffix
     * @return void
     */
    static function limit_latter( $string, $limit_length, $suffix = '...' ) {
        if ( strlen( $string ) > $limit_length ) {
            echo strip_shortcodes( substr( $string, 0, $limit_length ) . $suffix );
        } else {
            echo strip_shortcodes( esc_html( $string ) );
        }
    }

    /**
     * Get Version form filemtime
     *
     * @param string $filename
     * @param string $extention
     * @return void
     */
    static function get_version( $filename = '', $extention = 'css' ) {
        $min = ( WP_DEBUG === true ) ? '' : '.min';
        if( ! empty( $filename ) ) {
            return filemtime( REDIASCORE_PATH . '/assets/'. $extention .'/'. $filename . $min . '.'. $extention .'' );
        }else{
            return REDIASCORE_VERSION;
        }
    }

    /**
     * Animation Effect List
     *
     * @return void
     */
    static function get_animation_effects() {
        return [
            'dl-fadeIn'       => esc_html( 'Fade In', 'redias-core' ),
            'dl-fadeInLeft'   => esc_html( 'Fade In Left', 'redias-core' ),
            'dl-fadeInRight'  => esc_html( 'Fade In Right', 'redias-core' ),
            'dl-fadeInTop'    => esc_html( 'Fade In Top', 'redias-core' ),
            'dl-fadeInBottom' => esc_html( 'Fade In Bottom', 'redias-core' ),
            'dl-blurIn'       => esc_html( 'Blur In', 'redias-core' ),
            'dl-blurInLeft'   => esc_html( 'Blur In Left', 'redias-core' ),
            'dl-blurInRight'  => esc_html( 'Blur In Right', 'redias-core' ),
            'dl-blurInTop'    => esc_html( 'Blur In Top', 'redias-core' ),
            'dl-blurInBottom' => esc_html( 'Blur In Bottom', 'redias-core' ),
        ];
    }

    /**
     * Get elementor instance
     *
     * @return \Elementor\Plugin
     */
    static function elementor() {
        return \Elementor\Plugin::instance();
    }

    /**
     * Is Elemenotr Editor mode
     *
     * @param string $id
     * @return boolean
     */
    static function is_el_edit_mode( $id = '' ){
        $page_id = ! empty( $id ) ? $id : get_the_ID();
        return \Elementor\Plugin::$instance->editor->is_edit_mode($page_id);
    }

    /**
     * Get the list of all section templates
     *
     * @return array
     */
    static function get_section_templates() {
        $items = self::elementor()->templates_manager->get_source( 'local' )->get_items( ['type' => 'section'] );

        if ( ! empty( $items ) ) {
            $items = wp_list_pluck( $items, 'title', 'template_id' );
            return $items;
        } else {
            return [];
        }
    }

    /**
     * Slider Controls
     *
     * @param string $navigation
     * @param string $pagination
     * @param integer $style
     * @return void
     */
    static function get_slider_controls( $navigation = 'yes', $pagination = 'yes', $style = 1, $left_icon = 'long-arrow-alt-left', $right_icon = 'long-arrow-alt-right' ) {
        if( '1' === $style || 'yes' === $pagination ) : ?>
        <div class="dl-slider-controls style-<?php echo esc_attr( $style ); ?>">
        <?php
            if( 'yes' === $navigation && '1' === $style ) {
                echo '<div class="dl-slider-button-prev cursor-effect sound-effect"><i class="la la-'. esc_attr( $left_icon ) .'"></i></div>';
            }
            if( 'yes' === $pagination ) {
                echo '<div class="dl-swiper-pagination"></div>';
            }
            if( 'yes' === $navigation && '1' === $style ) {
                echo '<div class="dl-slider-button-next cursor-effect sound-effect"><i class="la la-'. esc_attr( $right_icon ) .'"></i></div>';
            }
        ?>
        </div>
        <?php
        endif;
        if( 'yes' === $navigation && '2' === $style ) {
            echo '<div class="dl-slider-button-prev cursor-effect sound-effect"><i class="la la-'. esc_attr( $left_icon ) .'"></i></div>';
            echo '<div class="dl-slider-button-next cursor-effect sound-effect"><i class="la la-'. esc_attr( $right_icon ) .'"></i></div>';
        }
    }

    /**
     * Get Terms
     *
     * @param string $taxonomy
     * @param integer $count
     * @param boolean $link
     * @param string $class
     * @param boolean $div
     * @return void
     */
    static function get_terms( $taxonomy="category", $count=1, $link=true, $class="dl-cat-item", $div=true ) {
		$dl_terms = get_the_terms( get_the_id(), $taxonomy );
		$dl_max_cat = $count;
		if( $dl_terms ) {
            if( $div === true ) {
                echo '<div class="dl-cat-items">';
            }
			foreach ( $dl_terms as $dl_term ) {
				$dl_cat = get_category( $dl_term );
				if( $link ) {
					printf( 
                        '<a href="%1$s" class="'. $class .'">%2$s</a>',
                        esc_url( get_category_link( $dl_cat->term_id ) ),
                        esc_html( $dl_cat->name )
                    );
				}else{
					printf( '<span>%1$s</span>', esc_html( $dl_cat->name ) );
				}
				
				$dl_max_cat--;

				if ( 0 == $dl_max_cat ) {
					break;
				}
			}
            if( $div === true ) {
                echo '</div>';
            }
		}
	}

    /**
     * Get Image Color
     *
     * @param [type] $url
     * @param [type] $hex
     * @param [type] $r
     * @param [type] $g
     * @param [type] $b
     * @return void
     */
    static function get_img_color( $url, $hex = null, $r = null, $g = null, $b = null ) {

        if ( $hex != null ) {
            $hex = str_replace("#", "", $hex);
            $r = hexdec(substr($hex, 0, 2));
            $g = hexdec(substr($hex, 2, 2));
            $b = hexdec(substr($hex, 4, 2));
        }
        
        if( function_exists('imagecreatefrompng') ) {
            $im = imagecreatefrompng($url);
            imageAlphaBlending($im, true);
            imageSaveAlpha($im, true);
        
            if (imageistruecolor($im)) {
                $sx = imagesx($im);
                $sy = imagesy($im);
                for ($x = 0; $x < $sx; $x++) {
                    for ($y = 0; $y < $sy; $y++) {
                        $c = imagecolorat($im, $x, $y);
                        $a = $c & 0xFF000000;
                        $newColor = $a | $r << 16 | $g << 8 | $b;
                        imagesetpixel($im, $x, $y, $newColor);
                    }
                }
            }
            ob_start();
        
            imagepng($im);
            imagedestroy($im);
            $image_data = ob_get_contents();
        
            ob_end_clean();
        
            $image_data_base64 = "data:image/png;base64," . base64_encode($image_data);
            return $image_data_base64;
        }else{
            return $url;
        }
        
    }

    /**
     * Return Trams
     *
     * @param string $terms
     * @return array
     */
    static function el_get_terms( $terms = 'category' ) {
        $post_categories = get_terms( $terms );

        $post_options = [];
        if ( ! empty( $post_categories ) ) {
            foreach ( $post_categories as $post_cat ) {
                if ( ! empty( $post_cat->slug ) ) {
                    $post_options[$post_cat->slug] = $post_cat->name;
                }
            }
        }

        return $post_options;
    }

    /**
     * Get contact form list
     *
     * @param integer $limit
     * @return array
     */
    static function el_get_contact_forms( $limit = -1 ) {
        $items = [];
        $args = array(
            'post_type' => 'wpcf7_contact_form', 
            'posts_per_page' => $limit 
        );
        if( $data = get_posts( $args ) ) {
            foreach( $data as $key ){
                $items[$key->ID] = $key->post_title;
            }
        }else{
            $items['0'] = esc_html__( 'No Contact Form found', 'redias-core' );
        }
        return $items;
    }

    /**
     * Get image sizes
     *
     * @return array
     */
    static function get_image_sizes() {
        $sizes = get_intermediate_image_sizes();
        $items = array();
        $items['full'] = 'full';
        foreach ( $sizes as $size ) {
            $items[$size] = $size;
        }

        return $items;
    }

    /**
     * Get post date link
     *
     * @return void
     */
    static function get_post_date_link() {
        $year  = get_the_time( 'Y' );
        $month = get_the_time( 'm' );
        $day   = get_the_time( 'd' );
        return get_day_link( $year, $month, $day );
    }

    /**
     * Get Featured Image
     *
     * @param string $size
     * @return void
     */
    static function get_featured_image_url( $size = 'full', $post_id = '' ) {
        if( ! empty( $post_id ) ) {
            $postid = $post_id;
        }else{
            global $wp_query;
            $postid = $wp_query->post->ID;
        }
        $image_array = wp_get_attachment_image_src( get_post_thumbnail_id( $postid ), $size );
        $image_url = ! empty( $image_array[0] ) ? $image_array[0] : '';
        return $image_url;
    }

    /**
     * Get Featured image with placeholder image
     *
     * @param string $size
     * @param [type] $post_id
     * @param string $place_img_url // URL of placeholder image
     * @return void
     */
    static function get_featured_img_with_placeholder_img( $size = 'full', $post_id = '', $place_img_url = '' ) {
        $postid = ! empty( $post_id ) ? $post_id : get_the_ID();
        $img_url = self::get_featured_image_url($size, $postid);
        if( ! empty( $img_url ) ) {
            return $img_url;
        }else{
            return $place_img_url;
        }
    }

    /**
     * Get Image URL by ID
     *
     * @param [type] $id
     * @param string $size
     * @return void
     */
    static function get_image_url_by_id( $id , $size = 'thumbnail' ) {
        if( empty( $id ) ) { return ''; }
        $img = wp_get_attachment_image_url( $id, $size );
        if( ! empty($img) ) {
            return $img;
        }else{
            return '';
        }
    }

    /**
     * Get image alt text by attachement ID
     *
     * @param [type] $image_id
     * @return void
     */
    static function get_image_alt_text( $image_id ) {
        $img_alt = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
        if( ! empty( get_the_title( $img_alt ) ) ) {
            return get_the_title($img_alt);
        }else{
            return 'Image';
        }
    }

    /**
     * @uses WP_Query
     * @uses get_queried_object()
     * @see get_the_ID()
     * @return int
     */
    static function get_the_post_id() {
        if ( in_the_loop() ) {
            $post_id = get_the_ID();
        } else {
            global $wp_query;
            $post_id = $wp_query->get_queried_object_id();
        }
        return $post_id;
    }

    /**
     * Get ACF Field Value
     *
     * @param [type] $v
     * @return [string, array, object]
     */
    static function get_field( $v ) {
        if ( function_exists( 'get_field' ) ) {
            $value = get_field( $v, self::get_the_post_id() );
        } else {
            $value = '';
        }
        return $value;
    }

    /**
     * Get ACF Field Value from post ID
     *
     * @param [type] $v
     * @param string $postid
     * @return string|array|object
     */
    static function get_field_by_id( $v, $postid = '' ) {
        $post_id = ! empty( $postid ) ? $postid : self::get_the_post_id();
        if ( function_exists( 'get_field' ) ) {
            $value = get_field( $v, $post_id );
        } else {
            $value = '';
        }
        return $value;
    }

    /**
     * Get CSF Option
     *
     * @param string $option
     * @param [type] $default
     * @return void
     */
    static function get_csf_option( $option = '', $default = null ) {
        $options = get_option( 'redias_opt' );
        return ( isset( $options[$option] ) ) ? $options[$option] : $default;
    }

    /**
     * Get Select Query
     *
     * @param string $post_type
     * @return array
     */
    static function get_select_query($post_type = 'post') {
        $options = array();

        $posts = get_posts( array(
            'post_type'  => $post_type,
            'numberposts' => -1
        ) );

        foreach ( $posts as $key => $post ) {
            $options[$post->ID] = get_the_title($post->ID);
        }

        return $options;
    }

    /**
     * Get product images
     *
     * @param [type] $settings
     * @return void
     */
    static function get_product_images( $settings = [], $gallery = false ) {
        $get_post_thumbnail = get_post_thumbnail_id();
        $gall_items = wc_get_product()->get_gallery_image_ids();
        
        if ( ! empty( $gall_items ) ) {
            $total_items = count( $gall_items );
            if( $total_items > 1 ) {
                $image_id = wc_get_product()->get_gallery_image_ids()[1];
            }else{
                $image_id = wc_get_product()->get_gallery_image_ids()[0];
            }
            $image_src = wp_get_attachment_image_src ( $image_id, 'full');
        }
        if ( ! empty( wc_get_product()->get_gallery_image_ids() && $image_src && $gallery === true )  ) :
            ?>
            <img src="<?php echo \Elementor\Group_Control_Image_Size::get_attachment_image_src( $get_post_thumbnail, 'thumbnail', $settings ); ?>" alt="<?php echo self::get_image_alt_text( $get_post_thumbnail ); ?>" class="front-img">	
            <img src="<?php echo \Elementor\Group_Control_Image_Size::get_attachment_image_src( $image_id, 'thumbnail', $settings ); ?>" alt="<?php echo self::get_image_alt_text( $image_id ); ?>" class="back-img">
            <?php else: ?>			                                
            <img src="<?php echo \Elementor\Group_Control_Image_Size::get_attachment_image_src( $get_post_thumbnail, 'thumbnail', $settings ); ?>" alt="<?php echo self::get_image_alt_text( $get_post_thumbnail ); ?>">	
        <?php endif;
    }

    /**
     * Is image format jpg
     *
     * @param string $url
     * @return boolean
     */
    static function is_img_format_jpg( $url = '' ) {
        if( ! empty( $url ) ) {
            $img_format = exif_imagetype( $url );
            if( 2 === $img_format ) {
                return true;
            }else{
                return false;
            }
        }else{
            return false;
        }
    }

    /**
     * Highlighted text
     *
     * @param [type] $text
     * @return string
     */
    static function get_highlighted_text( $text ) {
		return str_replace( array( '{{', '}}' ), array( '<span>', '</span>' ), $text );
	}

    /**
     * Isotope Filter Layout
     *
     * @param array $items
     * @param string $tax
     * @param string $all_text
     * @param string $cls
     * @return void
     */
    static function get_filter_layout( $items = [], $tax = 'project-category', $all_text = 'View All', $cls = 'project-filter' ) {
        if( $items ) :
        ?>
        <ul class="<?php echo esc_attr($cls); ?>">
            <li class="active" data-filter="*"><?php echo esc_html( $all_text ); ?></li>
            <?php 
            foreach( $items as $item ) {
                $term = get_term_by( 'slug', $item, $tax);
                echo '<li data-filter=".'. esc_attr( $tax ) . '-' . esc_attr( $item ) .'">'. esc_html( $term->name ) .'</li>';
            }
            ?>
        </ul>
        <?php
        endif;
    }

}