<?php
/**
 * Accordion
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Accordion;

use RediasCore\Classes\Helper;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-accordion';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Accordion', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-accordion';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return ['accordion', 'collapsible', 'toggle', 'redias'];
    }

    public function get_script_depends() {
        return ['redias-el-script'];
    }

    public function get_style_depends() {
        return [ 'redias-accordion', 'elementor-icons-fa-solid' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_accordion_content();
        $this->section_accordion_options();
        $this->accordion_item_style();
        $this->accordion_title_style();
        $this->accordion_icon_style();
        $this->accordion_content_style();
        $this->accordion_open_close_style();

    }

    /**
     * Accordion Content Controls
     *
     * @return void
     */
    protected function section_accordion_content() {

        $this->start_controls_section(
            'section_accordion',
            [
                'label' => esc_html__( 'Accordion', 'redias-core' ),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'title',
            [
                'type'        => Controls_Manager::TEXT,
                'label'       => esc_html__( 'Title', 'redias-core' ),
                'default'     => esc_html__( 'Accordion Title', 'redias-core' ),
                'placeholder' => esc_html__( 'Type Accordion Title', 'redias-core' ),
                'dynamic'     => [
                    'active' => true,
                ],
            ]
        );

        $repeater->add_control(
            'icon',
            [
                'type'       => Controls_Manager::ICONS,
                'label'      => esc_html__( 'Icon', 'redias-core' ),
                'show_label' => false,
            ]
        );

        $repeater->add_control(
            'source',
            [
                'type'      => Controls_Manager::SELECT,
                'label'     => esc_html__( 'Content Source', 'redias-core' ),
                'default'   => 'editor',
                'separator' => 'before',
                'options'   => [
                    'editor'   => esc_html__( 'Editor', 'redias-core' ),
                    'template' => esc_html__( 'Template', 'redias-core' ),
                ],
            ]
        );

        $repeater->add_control(
            'editor',
            [
                'label'      => esc_html__( 'Content Editor', 'redias-core' ),
                'show_label' => false,
                'type'       => Controls_Manager::WYSIWYG,
                'condition'  => [
                    'source' => 'editor',
                ],
                'dynamic'    => [
                    'active' => true,
                ],
            ]
        );

        $repeater->add_control(
            'template',
            [
                'label'       => esc_html__( 'Section Template', 'redias-core' ),
                'placeholder' => esc_html__( 'Select a section template for as tab content', 'redias-core' ),
                'description' => sprintf( esc_html__( 'Wondering what is section template or need to create one? Please click %1$shere%2$s ', 'redias-core' ),
                    '<a target="_blank" href="' . esc_url( admin_url( '/edit.php?post_type=elementor_library&tabs_group=library&elementor_library_type=section' ) ) . '">',
                    '</a>'
                ),
                'label_block' => true,
                'type'        => Controls_Manager::SELECT2,
                'options'     => Helper::get_section_templates(),
                'condition'   => [
                    'source' => 'template',
                ],
            ]
        );

        $this->add_control(
            'tabs',
            [
                'show_label'  => false,
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{title}}',
                'default'     => [
                    [
                        'title'  => 'Accordion Item 1',
                        'source' => 'editor',
                        'editor' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore <br><br>et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.',
                    ],
                    [
                        'title'  => 'Accordion Item 2',
                        'source' => 'editor',
                        'editor' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore <br><br>et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.',
                    ],
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Accordion Options
     *
     * @return void
     */
    protected function section_accordion_options() {

        $this->start_controls_section(
            'section_options',
            [
                'label' => esc_html__( 'Options', 'redias-core' ),
            ]
        );

        $this->add_control(
            'closed_icon',
            [
                'type'    => Controls_Manager::ICONS,
                'label'   => esc_html__( 'Closed Icon', 'redias-core' ),
                'default' => [
                    'library' => 'solid',
                    'value'   => 'fas fa-plus',
                ],
            ]
        );

        $this->add_control(
            'opened_icon',
            [
                'type'    => Controls_Manager::ICONS,
                'label'   => esc_html__( 'Opened Icon', 'redias-core' ),
                'default' => [
                    'library' => 'solid',
                    'value'   => 'fas fa-minus',
                ],
            ]
        );

        $this->add_control(
            'icon_position',
            [
                'type'           => Controls_Manager::CHOOSE,
                'label'          => esc_html__( 'Position', 'redias-core' ),
                'default'        => 'left',
                'toggle'         => false,
                'options'        => [
                    'left'  => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'prefix_class'   => 'dl-accordion--icon-',
                'style_transfer' => true,
                'selectors_dictionary' => [
                    'left' => 'justify-content: flex-start;flex-direction: inherit;',
                    'right' => 'justify-content: space-between;flex-direction: row-reverse;',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-accordion__item-title' => '{{VALUE}}'
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Accordion Item Style
     *
     * @return void
     */
    protected function accordion_item_style() {

        $this->start_controls_section(
            'section_style_accordion_item',
            [
                'label' => esc_html__( 'Item', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'item_spacing',
            [
                'label'     => esc_html__( 'Vertical Spacing (px)', 'redias-core' ),
                'type'      => Controls_Manager::NUMBER,
                'step'      => 'any',
                'default'   => -1,
                'selectors' => [
                    '{{WRAPPER}} .dl-accordion__item:not(:first-child)' => 'margin-top: {{VALUE}}px;',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'item_border',
                'label'    => esc_html__( 'Box Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-accordion__item',
            ]
        );

        $this->add_control(
            'item_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-accordion__item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'item_box_shadow',
                'label'    => esc_html__( 'Box Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-accordion__item',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Accordion Title Style
     *
     * @return void
     */
    protected function accordion_title_style() {

        $this->start_controls_section(
            'section_style_acc_title',
            [
                'label' => esc_html__( 'Title', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-accordion__item-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .dl-accordion__item-title',
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'     => 'title_text_shadow',
                'label'    => esc_html__( 'Text Shadow', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-accordion__item-title',
            ]
        );

        $this->start_controls_tabs( '_tab_tab_status' );

        $this->start_controls_tab(
            '_tab_tab_normal',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
            ]
        );

        $this->add_control(
            'title_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-accordion__item-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-accordion__item-title-text, {{WRAPPER}} .dl-accordion__item-title-icon i:before, {{WRAPPER}} .dl-accordion__icon i:before' => 'color: {{VALUE}};',
                ],
                'default'   => '#fff',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'title_bg',
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .dl-accordion__item-title',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'title_border',
                'label'    => esc_html__( 'Border', 'textdomain' ),
                'selector' => '{{WRAPPER}} .dl-accordion__item-title',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            '_tab_tab_active',
            [
                'label' => esc_html__( 'Active', 'redias-core' ),
            ]
        );

        $this->add_control(
            'title_active_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-accordion__item-title.dl-accordion__item--active' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_active_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-accordion__item-title.dl-accordion__item--active .dl-accordion__item-title-text, {{WRAPPER}} .dl-accordion__item-title.dl-accordion__item--active .dl-accordion__item-title-icon i:before, {{WRAPPER}} .dl-accordion__item-title.dl-accordion__item--active .dl-accordion__icon i:before' => 'color: {{VALUE}};',
                ],
                'default'   => '#fff',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'title_active_bg',
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .dl-accordion__item-title.dl-accordion__item--active',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'title_active_border',
                'label'    => esc_html__( 'Border', 'textdomain' ),
                'selector' => '{{WRAPPER}} .dl-accordion__item-title.dl-accordion__item--active',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();
    }

    /**
     * Accordion Icon Style
     *
     * @return void
     */
    protected function accordion_icon_style() {

        $this->start_controls_section(
            'section_style_acc_title_icon',
            [
                'label' => esc_html__( 'Title Icon', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'closed_title_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} span.dl-accordion__item-title-icon i:before' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'active_title_icon_color',
            [
                'label'     => esc_html__( 'Active Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-accordion__item-title.dl-accordion__item--active span.dl-accordion__item-title-icon i:before' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_icon_spacing',
            [
                'label'      => esc_html__( 'Spacing', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-accordion__item-title' => 'column-gap: {{SIZE}}px;',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Accordion Content Style
     *
     * @return void
     */
    protected function accordion_content_style() {

        $this->start_controls_section(
            'section_style_acc_content',
            [
                'label' => esc_html__( 'Content', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-accordion__item-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'content_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-accordion__item-content',
            ]
        );

        $this->add_control(
            'content_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-accordion__item-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'content_typography',
                'selector' => '{{WRAPPER}} .dl-accordion__item-content',
            ]
        );

        $this->add_control(
            'content_color',
            [
                'label'     => esc_html__( 'Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-accordion__item-content' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'content_bg',
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-accordion__item-content',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Accordion Open Close Icon Style
     *
     * @return void
     */
    protected function accordion_open_close_style() {

        $this->start_controls_section(
            'section_style_acc_openclose',
            [
                'label' => esc_html__( 'Open / Close Icon', 'redias-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'closed_icon_color',
            [
                'label'     => esc_html__( 'Closed Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-accordion__icon span.dl-accordion__icon--closed i:before' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'opened_icon_color',
            [
                'label'     => esc_html__( 'Opened Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-accordion__item-title.dl-accordion__item--active .dl-accordion__icon span.dl-accordion__icon--opened i:before' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'nav_icon_spacing',
            [
                'label'      => esc_html__( 'Spacing', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}}.dl-accordion--icon-left .dl-accordion__icon > span'  => 'margin-right: {{SIZE}}px;',
                    '{{WRAPPER}}.dl-accordion--icon-right .dl-accordion__icon > span' => 'margin-left: {{SIZE}}px;',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

		$settings = $this->get_settings_for_display();

        if ( ! is_array( $settings['tabs'] ) || empty( $settings['tabs'] ) ) {
            return;
        }

        $has_closed_icon = ( ! empty( $settings['closed_icon'] ) && ! empty( $settings['closed_icon']['value'] ) );
        $has_opened_icon = ( ! empty( $settings['opened_icon'] ) && ! empty( $settings['opened_icon']['value'] ) );

        $id_int = substr( $this->get_id_int(), 0, 3 );
        ?>
        <div class="dl-accordion__wrapper" role="tablist">
            <?php foreach ( $settings['tabs'] as $index => $item ) :
                $count = $index + 1;

                $title_setting_key = $this->get_repeater_setting_key( 'title', 'tabs', $index );
                $has_title_icon = ( ! empty( $item['icon'] ) && ! empty( $item['icon']['value'] ) );

                if ( $item['source'] === 'editor' ) {
                    $content_setting_key = $this->get_repeater_setting_key( 'editor', 'tabs', $index );
                    $this->add_inline_editing_attributes( $content_setting_key, 'advanced' );
                } else {
                    $content_setting_key = $this->get_repeater_setting_key( 'section', 'tabs', $index );
                }

                $this->add_render_attribute( $title_setting_key, [
                    'id' => 'dl-accordion__item-title-' . $id_int . $count,
                    'class' => [ 'dl-accordion__item-title' ],
                    'data-tab' => $count,
                    'role' => 'tab',
                    'aria-controls' => 'dl-accordion__item-content-' . $id_int . $count,
                ] );

                $this->add_render_attribute( $content_setting_key, [
                    'id' => 'dl-accordion__item-content-' . $id_int . $count,
                    'class' => [ 'dl-accordion__item-content' ],
                    'data-tab' => $count,
                    'role' => 'tabpanel',
                    'aria-labelledby' => 'dl-accordion__item-title-' . $id_int . $count,
                ] );

                ?>
                <div class="dl-accordion__item">
                    <div <?php echo $this->get_render_attribute_string( $title_setting_key ); ?>>
                        <?php if ( $has_opened_icon || $has_closed_icon ) : ?>
                            <span class="dl-accordion__item-icon dl-accordion__icon" aria-hidden="true">
                                <?php if ( $has_opened_icon ) : ?>
                                    <span class="dl-accordion__icon--closed"><?php Helper::render_icon( $settings, false, 'closed_icon' ); ?></span>
                                <?php endif; ?>
                                <?php if ( $has_opened_icon ) : ?>
                                    <span class="dl-accordion__icon--opened"><?php Helper::render_icon( $settings, false, 'opened_icon' ); ?></span>
                                <?php endif; ?>
                            </span>
                        <?php endif; ?>
                        <div class="dl-accordion__item-title-inner">
                            <?php if ( $has_title_icon ) : ?>
                                <span class="dl-accordion__item-title-icon"><?php Helper::render_icon( $item, false, 'icon' ); ?></span>
                            <?php endif; ?>
                            <span class="dl-accordion__item-title-text"><?php echo Helper::kses_basic( $item['title'] ); ?></span>
                        </div>
                    </div>
                    <div <?php echo $this->get_render_attribute_string( $content_setting_key ); ?>>
                        <?php
                        if ( $item['source'] === 'editor' ) :
                            echo $this->parse_text_editor( $item['editor'] );
                        elseif ( $item['source'] === 'template' && $item['template'] ) :
                            echo Helper::elementor()->frontend->get_builder_content_for_display( $item['template'] );
                        endif;
                        ?>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <?php

    }

}