<?php
/**
 * Google Map
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\GoogleMap;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    public function __construct($data = [], $args = null) {
		parent::__construct($data, $args);
        wp_register_script( 'mapmarker', REDIASCORE_ASSETS . '/js/lib/mapmarker.jquery.js', [ 'jquery' ], NULL, true );
        $options = get_option( 'redias_opt' );
        $google_map_api_key = ! empty( $options['google_map_api_key'] ) ? $options['google_map_api_key'] : '';
        if( ! empty( $google_map_api_key ) ){
            wp_register_script( 'google-map-api', 'https://maps.googleapis.com/maps/api/js?key='.$google_map_api_key, array('jquery'), NULL, TRUE );
        }else{
            wp_register_script( 'google-map-api', 'http://maps.googleapis.com/maps/api/js?sensor=false', array('jquery'), NULL, TRUE );
        }
    }

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-google-map';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Google Map', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-google-maps';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return ['newsletter', 'mc', 'mailchimp', 'redias'];
    }

    public function get_script_depends() {
        return [ 'google-map-api', 'mapmarker', 'redias-el-script' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_gmap_content();
        $this->section_map_marker();
        
    }

    /**
     * Google Map Content
     *
     * @return void
     */
    protected function section_gmap_content() {
        
        $this->start_controls_section(
            'google_map_content',
            [
                'label' => __( 'Google Map', 'redias-core' ),
            ]
        );
            
            $this->add_control(
                'zoom_control',
                [
                    'label' => __( 'Zoom Control', 'redias-core' ),
                    'type' => Controls_Manager::SWITCHER,
                    'return_value' => 'yes',
                    'default' => 'no',
                ]
            );

            $this->add_control(
                'dl_map_default_zoom',
                [
                    'label' => __( 'Default Zoom', 'redias-core' ),
                    'type' => Controls_Manager::SLIDER,
                    'default' => [
                        'size' => 5,
                    ],
                    'range' => [
                        'px' => [
                            'min' => 1,
                            'max' => 24,
                        ],
                    ],
                    'condition' => [
                        'zoom_control' => 'yes',
                    ]
                ]
            );

            $this->add_responsive_control(
                'dl_google_map_height',
                [
                    'label' => __( 'Map Height', 'redias-core' ),
                    'type'  => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max' => 1000,
                        ],
                    ],
                    'default' => [
                        'unit' => 'px',
                        'size' => 500,
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .dl-google-map'  => 'min-height: {{SIZE}}{{UNIT}}',
                    ],
                ]
            );

            $this->add_control(
                'dl_center_address',
                [
                    'label' => __( 'Center Address', 'redias-core' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'placeholder' => __( 'Enter your center address.', 'redias-core' ),
                    'default' => __( 'New York', 'redias-core' ),
                ]
            );

            $this->add_control(
                'dl_style_address',
                [
                    'label' => __( 'Map Style', 'redias-core' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'placeholder' => __( 'Enter Map Style Json Code.', 'redias-core' ),
                    'description'   => __( 'Go to <a href="https://snazzymaps.com/" target=_blank>Snazzy Maps</a> and Choose/Customize your Map Style. Click on your demo and copy JavaScript Style Array', 'redias-core' )
                ]
            );

        $this->end_controls_section();

    }

    /**
     * Map Marker
     *
     * @return void
     */
    protected function section_map_marker() {
        
        $this->start_controls_section(
            'google_map_marker',
            [
                'label' => __( 'Map Marker', 'redias-core' ),
            ]
        );
        
            $this->add_control(
                'dl_map_marker_list',
                [
                    'label' => __( 'Marker', 'redias-core' ),
                    'type' => Controls_Manager::REPEATER,
                    'default' => [
                        [
                            'marker_title'   => __('This is <strong>Dhaka</strong>','redias-core'),
                            'marker_lat'   => __('23.8103','redias-core'),
                            'marker_lng'   => __('90.4125','redias-core'),
                            'custom_marker'   => __('90.4125','redias-core'),
                        ]

                    ],

                    'fields' => [
                        
                        [
                            'name'        => 'marker_lat',
                            'label'       => __( 'Latitude', 'redias-core' ),
                            'type'        => Controls_Manager::TEXT,
                            'default'     => '31.42866311735861',
                        ],

                        [
                            'name'        => 'marker_lng',
                            'label'       => __( 'Longitude', 'redias-core' ),
                            'type'        => Controls_Manager::TEXT,
                            'default'     => '-98.61328125',
                        ],

                        [
                            'name' => 'marker_title',
                            'label' => esc_html__( 'Title', 'redias-core' ),
                            'type'  => Controls_Manager::TEXTAREA,
                            'default' => __('Another Place','redias-core'),
                        ],

                        [
                            'name'        => 'custom_marker',
                            'label'       => esc_html__( 'Custom marker', 'dl-addon' ),
                            'description' => esc_html__('Use max 32x32 px size.', 'redias-core'),
                            'type'        => Controls_Manager::MEDIA,
                        ],

                    ],
                    'title_field' => '{{{ marker_title }}}',
                ]
            );

        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

		$settings   = $this->get_settings_for_display();

        $map_options     = [];
        $marker_opts     = [];
        $all_markerslist = [];
        foreach ( $settings['dl_map_marker_list'] as $marker_item ) {
            $marker_opts['latitude'] = ( $marker_item['marker_lat'] ) ? $marker_item['marker_lat'] : '';
            $marker_opts['longitude'] = ( $marker_item['marker_lng'] ) ? $marker_item['marker_lng'] : '';
            $marker_opts['baloon_text'] = ( $marker_item['marker_title'] ) ? $marker_item['marker_title'] : '';
            $marker_opts['icon'] = ( $marker_item['custom_marker']['url'] ) ? $marker_item['custom_marker']['url'] : '';
            $all_markerslist[] = $marker_opts;
        };
        $map_options['zoom'] = !empty( $settings['dl_map_default_zoom']['size'] ) ? $settings['dl_map_default_zoom']['size'] : 5;
        $map_options['center'] = !empty( $settings['dl_center_address'] ) ? $settings['dl_center_address'] : 'Bangladesh';

        $this->add_render_attribute( 'googlemaps_attr', 'class', 'dl-google-map' );
        $this->add_render_attribute( 'googlemaps_attr', 'id', 'dl-google-map' );
        $this->add_render_attribute( 'googlemaps_attr', 'data-mapmarkers', wp_json_encode( $all_markerslist ) );
        $this->add_render_attribute( 'googlemaps_attr', 'data-mapoptions', wp_json_encode( $map_options ) );
        $this->add_render_attribute( 'googlemaps_attr', 'data-mapstyle', $settings['dl_style_address'] );

        ?>
            <div <?php echo $this->get_render_attribute_string('googlemaps_attr'); ?> >&nbsp;</div>
        <?php

    }

}