<?php
/**
 * List Items
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\ListItems;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Icons_Manager;
use Elementor\Repeater;
use Elementor\Widget_Base;

use RediasCore\Classes\Helper;
use RediasCore\Elementor\Controls\Foreground;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-list-items';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'List', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-post-list';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return ['icon list', 'list', 'icon', 'redias'];
    }

    public function get_style_depends() {
        return [ 'elementor-icons-fa-solid' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_layout();
        $this->section_list_items();
        $this->box_style();
        $this->icon_style();
        $this->heading_style();
        $this->description_style();
        $this->readmore_style();

    }

    /**
     * Layout Section
     *
     * @return void
     */
    protected function section_layout() {
        
        $this->start_controls_section(
            'section_layout',
            [
                'label' => esc_html__( 'Layout', 'redias-core' ),
            ]
        );

        $this->add_responsive_control(
            'layout',
            [
                'label'   => esc_html__( 'Layout', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'block'   => [
                        'title' => esc_html__( 'Block', 'redias-core' ),
                        'icon'  => 'eicon-editor-list-ul',
                    ],
                    'inline' => [
                        'title' => esc_html__( 'Inline', 'redias-core' ),
                        'icon'  => 'eicon-navigation-horizontal',
                    ],
                ],
                'default' => 'block',
                'toggle'  => false,
                'prefix_class' => 'layout-',
                'selectors_dictionary' => [
                    'inline' => 'display: grid',
                    'block' => 'display: block',
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-el-items' => '{{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'column',
            [
                'label'      => esc_html__( 'Column', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 1,
                        'max'  => 6
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 2,
                ],
                'selectors'  => [
                    '{{WRAPPER}}.layout-inline .dl-el-items' => 'grid-template-columns: repeat({{SIZE}}, 1fr);',
                ],
                'condition'    => [
                    'layout'    => 'inline',
                ],
            ]
        );

        $this->add_responsive_control(
            'space_between_item',
            [
                'label'      => esc_html__( 'Space Between Item', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 20
                ],
                'selectors'  => [
                    '{{WRAPPER}}.layout-block .dl-el-items .dl-el-item:not(:last-of-type)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}}.layout-inline .dl-el-items' => 'gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'alignment',
            [
                'label'   => esc_html__( 'Alignment', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'prefix_class' => 'align-',
                'default' => 'left',
                'toggle'  => false,
                'selectors' => [
                    '{{WRAPPER}} .dl-el-items .dl-el-list-content' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}}.align-center .dl-el-items .dl-el-list-icon' => 'margin: 0 auto;',
                    '{{WRAPPER}}.align-right .dl-el-items .dl-el-list-icon' => 'margin-left: auto;',
                ],
                'condition'    => [
                    'icon_postion'    => 'top',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Section List Items
     *
     * @return void
     */
    protected function section_list_items() {

        $this->start_controls_section(
            'section_items',
            [
                'label' => esc_html__( 'List Items', 'redias-core' ),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'icon',
            [
                'label'   => esc_html__( 'Icon', 'redias-core' ),
                'type'    => Controls_Manager::ICONS,
                'default' => [
                    'value'   => 'fas fa-check',
                    'library' => 'solid',
                ],
            ]
        );

        $repeater->add_control(
            'heading', [
                'label'       => esc_html__( 'Heading', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Business Solution', 'redias-core' ),
                'label_block' => true,
            ]
        );
        
        $repeater->add_control(
            'description',
            [
                'label'       => esc_html__( 'Description', 'redias-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'rows'        => 5,
                'placeholder' => esc_html__( 'Description goes here...', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'readmore_text',
            [
                'label'       => __( 'Readmore Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Text goes here...', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'link',
            [
                'label'         => esc_html__( 'Link', 'redias-core' ),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_html__( 'https://your-link.com', 'redias-core' ),
                'show_external' => true,
                'default'       => [
                    'url'         => '',
                    'is_external' => false,
                    'nofollow'    => true,
                ],
                'condition'    => [
                    'readmore_text!'    => ''
                ],
            ]
        );

        $repeater->add_control(
            'customize',
            [
                'label'        => esc_html__( 'Want To Customize?', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'description'  => esc_html__( 'You can customize this list from here.', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'background-color: {{VALUE}}',
                ],
                'condition' => ['customize' => 'yes'],
            ]
        );

        $repeater->add_control(
            'icon_bg_color',
            [
                'label'     => esc_html__( 'Icon Background', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .dl-el-list-icon' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'customize' => 'yes',
                    'icon[value]!' => ''
                ],
            ]
        );

        $repeater->add_control(
            'icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .dl-el-list-icon' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'customize' => 'yes',
                    'icon[value]!' => ''
                ],
            ]
        );

        $repeater->add_control(
            'heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .dl-el-list-content h3' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'customize' => 'yes',
                    'heading!' => ''
                ],
            ]
        );

        $repeater->add_control(
            'description_color',
            [
                'label'     => esc_html__( 'Description Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .dl-el-list-content p' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'customize' => 'yes',
                    'description!' => ''
                ],
            ]
        );

        $repeater->add_control(
            'readmore_color',
            [
                'label'     => esc_html__( 'Readmore Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .dl-el-list-content a' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'customize' => 'yes',
                    'readmore_text!' => '',
                    'link[url]!' => ''
                ],
            ]
        );

        $repeater->add_control(
            'readmore_hover_color',
            [
                'label'     => esc_html__( 'Readmore Hover Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .dl-el-list-content a:hover' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'customize' => 'yes',
                    'readmore_text!' => '',
                    'link[url]!' => ''
                ],
            ]
        );
        
        $this->add_control(
            'list_items',
            [
                'label'       => esc_html__( 'List Items', 'redias-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'icon'   => [
                            'value'   => 'fas fa-check',
                            'library' => 'fa-solid',
                        ],
                        'heading' => esc_html__( 'Business Solution'),
                        'description' => esc_html__( 'We develop highly complex technical projects geared to improving people\'s quality of life.', 'redias-core' ),
                    ],
                    [
                        'icon'   => [
                            'value'   => 'fas fa-check',
                            'library' => 'fa-solid',
                        ],
                        'heading' => esc_html__( 'Data Analytics'),
                        'description' => esc_html__( 'We develop highly complex technical projects geared to improving people\'s quality of life.', 'redias-core' ),
                    ],
                    [
                        'icon' => [
							'value' => 'fas fa-check',
							'library' => 'fa-solid',
						],
                        'heading' => esc_html__( 'Market Strategy'),
                        'description' => esc_html__( 'We develop highly complex technical projects geared to improving people\'s quality of life.', 'redias-core' ),
                    ],
                ],
                'title_field' => '{{{ elementor.helpers.renderIcon( this, icon, {}, "i", "panel" ) }}} {{{ heading }}}',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Box Style
     *
     * @return void
     */
    protected function box_style() {
        
        $this->start_controls_section(
            'box_style_section',
            [
                'label' => esc_html__( 'Box', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'box_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .dl-el-item',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'box_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-item',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'item_box_shadow',
                'selector' => '{{WRAPPER}} .dl-el-item',
            ]
        );

        $this->add_responsive_control(
            'box_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'box_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Icon Style
     *
     * @return void
     */
    protected function icon_style() {
        
        $this->start_controls_section(
            'icon_style_section',
            [
                'label' => esc_html__( 'Icon', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'icon_control',
            [
                'label'   => esc_html__( 'Icon', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'show'   => [
                        'title' => esc_html__( 'Show', 'redias-core' ),
                        'icon'  => 'eicon-eye',
                    ],
                    'hide' => [
                        'title' => esc_html__( 'Hide', 'redias-core' ),
                        'icon'  => 'eicon-ban',
                    ],
                ],
                'prefix_class' => 'icon-',
                'default' => 'show',
                'selectors' => [
                    '{{WRAPPER}}.icon-hide .dl-el-items .dl-el-item' => 'grid-template-columns: 1fr;'
                ],
                'toggle'  => false,
            ]
        );
        
        $this->add_control(
            'icon_postion',
            [
                'label'   => esc_html__( 'Icon Position', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'top' => [
                        'title' => esc_html__( 'Top', 'redias-core' ),
                        'icon'  => 'eicon-v-align-top',
                    ]
                ],
                'prefix_class' => 'list-',
                'default' => 'left',
                'toggle'  => false,
                'condition'    => [
                   'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_alignment',
            [
                'label'   => esc_html__( 'Icon Alignment', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'top'   => [
                        'title' => esc_html__( 'Top', 'redias-core' ),
                        'icon'  => 'eicon-v-align-top',
                    ],
                    'middle' => [
                        'title' => esc_html__( 'Middle', 'redias-core' ),
                        'icon'  => 'eicon-v-align-middle',
                    ],
                    'bottom'  => [
                        'title' => esc_html__( 'Bottom', 'redias-core' ),
                        'icon'  => 'eicon-v-align-bottom',
                    ],
                ],
                'default' => 'top',
                'selectors_dictionary' => [
                    'top' => 'align-items: flex-start',
                    'middle' => 'align-items: center',
                    'bottom' => 'align-items: flex-end'
                ],
                'selectors' => [
                    '{{WRAPPER}} .dl-el-items .dl-el-item' => '{{VALUE}}'
                ],
                'toggle'  => false,
                'condition'    => [
                   'icon_postion'    => 'left',
                   'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'icon_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .dl-el-items .dl-el-item .dl-el-list-icon',
                'condition'    => [
                    'icon_control'    => 'show',
                 ],
            ]
        );

        $this->add_control(
			'hr_icon_bg',
			[
				'type' => Controls_Manager::DIVIDER,
                'condition'    => [
                    'icon_control'    => 'show',
                ],
			]
		);

        $this->add_control(
			'icon_color_heading',
			[
				'label' => esc_html__( 'Icon Color', 'redias-core' ),
				'type' => Controls_Manager::HEADING,
                'condition'    => [
                    'icon_control'    => 'show',
                ],
			]
		);

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'icon_color',
                'label'    => esc_html__( 'Icon Color', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-el-items .dl-el-item .dl-el-list-icon i',
                'condition'    => [
                    'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_control(
            'svg_icon_color',
            [
                'label'     => esc_html__( 'SVG Icon Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .dl-el-items .dl-el-item .dl-el-list-icon svg' => 'fill: {{VALUE}}',
                ],
                'condition'    => [
                    'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_width',
            [
                'label'      => esc_html__( 'Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 300,
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 60,
                ],
                'selectors'  => [
                    '{{WRAPPER}}.list-left .dl-el-items .dl-el-item' => 'grid-template-columns: {{SIZE}}{{UNIT}} 1fr;',
                    '{{WRAPPER}}.list-top .dl-el-items .dl-el-item' => 'grid-template-columns: 1fr;',
                    '{{WRAPPER}}.list-top .dl-el-items .dl-el-item .dl-el-list-icon' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_height',
            [
                'label'      => esc_html__( 'Height', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 300,
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 60,
                ],
                'selectors'  => [
                    '{{WRAPPER}}.list-left .dl-el-items .dl-el-item .dl-el-list-icon' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}}.list-top .dl-el-items .dl-el-item .dl-el-list-icon' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_space_between',
            [
                'label'      => esc_html__( 'Space Between', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 200,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 15,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-items .dl-el-item' => 'grid-gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_size',
            [
                'label'      => esc_html__( 'Icon Size', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 300,
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 30,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-items .dl-el-item .dl-el-list-icon' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .dl-el-items .dl-el-item .dl-el-list-icon svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
                    'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'icon_box_shadow',
                'selector' => '{{WRAPPER}} .dl-el-items .dl-el-item .dl-el-list-icon',
                'condition'    => [
                    'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'icon_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-items .dl-el-item .dl-el-list-icon',
                'condition'    => [
                    'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-items .dl-el-item .dl-el-list-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-items .dl-el-item .dl-el-list-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'icon_control'    => 'show',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-items .dl-el-item .dl-el-list-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'icon_control'    => 'show',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Heading Style
     *
     * @return void
     */
    protected function heading_style() {
        
        $this->start_controls_section(
            'heading_style_section',
            [
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'heading_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-item .dl-el-list-content h3',
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'heading_color',
                'label'    => esc_html__( 'Text Color', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dl-el-item .dl-el-list-content h3',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'heading_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-item .dl-el-list-content h3',
            ]
        );

        $this->add_responsive_control(
            'heading_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content h3' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Description Style
     *
     * @return void
     */
    protected function description_style() {
        
        $this->start_controls_section(
            'desc_style_section',
            [
                'label' => esc_html__( 'Description', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'desc_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-item .dl-el-list-content p',
            ]
        );

        $this->add_control(
            'desc_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'desc_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-item .dl-el-list-content p',
            ]
        );

        $this->add_responsive_control(
            'desc_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content p' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Readmore Style
     *
     * @return void
     */
    protected function readmore_style() {
        
        $this->start_controls_section(
            'readmore_style_section',
            [
                'label' => esc_html__( 'Readmore', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'readmore_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-item .dl-el-list-content a',
            ]
        );

        $this->add_responsive_control(
            'readmore_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'readmore_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs( 'reamore_style_tabs' );
        
        $this->start_controls_tab(
            'reamore_style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'readmore_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'   => ['image'],
                'selector' => '{{WRAPPER}} .dl-el-item .dl-el-list-content a',
            ]
        );

        $this->add_control(
            'readmore_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'readmore_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-item .dl-el-list-content a',
            ]
        );

        $this->add_responsive_control(
            'readmore_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'reamore_style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'redias-core' ),
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'readmore_hover_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'   => ['image'],
                'selector' => '{{WRAPPER}} .dl-el-item .dl-el-list-content a:hover',
            ]
        );

        $this->add_control(
            'readmore_hover_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'readmore_hover_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .dl-el-item .dl-el-list-content a:hover',
            ]
        );

        $this->add_responsive_control(
            'readmore_h_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .dl-el-item .dl-el-list-content a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        $this->add_render_attribute( 'wrapper', 'class', 'dl-el-items' );
        $list_items = $settings['list_items'];
        if( $list_items ) :
        ?>
        <div class="dl-el-items">
            <?php 
            foreach ( $list_items as $index => $item ) : 
                $repeater_setting_key_heading = $this->get_repeater_setting_key( 'heading', 'list_items', $index );
                $this->add_inline_editing_attributes( $repeater_setting_key_heading );
                $repeater_setting_key_desc = $this->get_repeater_setting_key( 'description', 'list_items', $index );
                $this->add_inline_editing_attributes( $repeater_setting_key_desc );
                $repeater_setting_key_readmore = $this->get_repeater_setting_key( 'readmore_text', 'list_items', $index );
                $this->add_inline_editing_attributes( $repeater_setting_key_readmore );
                if ( ! empty( $item['link']['url'] ) ) {
                    $link_key = 'link_' . $index;
                    $this->add_link_attributes( $link_key, $item['link'] );
                }
            ?>
            <div class="dl-el-item elementor-repeater-item-<?php echo $item['_id']; ?>">
                <?php if( $item['icon'] && 'show' === $settings['icon_control'] ) : ?>
                    <div class="dl-el-list-icon">
                        <?php Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] ); ?>
                    </div>
                <?php endif; ?>
                <div class="dl-el-list-content">
                    <?php if( $item['heading'] ) : ?>
                        <h3 <?php $this->print_render_attribute_string( $repeater_setting_key_heading ); ?>><?php echo Helper::kses_basic( $item['heading'] ); ?></h3>
                    <?php endif; ?>
                    <?php if( $item['description'] ) : ?>
                        <p <?php $this->print_render_attribute_string( $repeater_setting_key_desc ); ?>><?php echo Helper::kses_basic( $item['description'] ); ?></p>
                    <?php endif; ?>
                    <?php if( ! empty( $item['readmore_text'] && $item['link']['url'] ) ) : ?>
                        <a <?php $this->print_render_attribute_string( $link_key ); ?> <?php $this->print_render_attribute_string( $repeater_setting_key_readmore ); ?>><?php echo esc_html( $item['readmore_text'] ); ?></a>
                    <?php endif; ?>
                </div>
            </div>
            <?php endforeach; ?>
        </div>
        <?php
        endif;
    }

}