<?php
/**
 * Page Header
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\PageHeader;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Widget_Base;

use RediasCore\Classes\Helper;
use RediasCore\Elementor\Controls\Foreground;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-page-header';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Page Header', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-header';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return ['header', 'page header', 'banner', 'redias'];
    }

    public function get_style_depends() {
        return ['redias-page-header'];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->layout_section();
        $this->content_section();
        $this->background_style();
        $this->sub_heading_style();
        $this->heading_style();
        $this->description_style();
        $this->shape_style();
        $this->breadcrumb_style();
        $this->bottom_border_style();

    }

    /**
     * Layout Section
     *
     * @return void
     */
    protected function layout_section() {

        $this->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__( 'Layout', 'redias-core' ),
            ]
        );

        $this->add_responsive_control(
            'alignment',
            [
                'label'   => esc_html__( 'Alignment', 'redias-core' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'redias-core' ),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'redias-core' ),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__( 'Right', 'redias-core' ),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default' => 'left',
                'prefix_class' => 'align-',
                'selectors_dictionary' => [
                    'left' => 'justify-content: flex-start; text-align: left',
                    'center' => 'justify-content: center; text-align: center',
                    'right' => 'justify-content: flex-end; text-align: left'
                ],
                'selectors' => [
                    '{{WRAPPER}} .el-page-header>.container' => '{{VALUE}}',
                    '{{WRAPPER}}.align-right .el-page-header-shape' => '-webkit-transform: scaleX(-1); transform: scaleX(-1);',
                ],
                'toggle'  => false,
            ]
        );

        $this->add_responsive_control(
            'height',
            [
                'label'      => esc_html__( 'Height', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', 'vh'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 1000,
                        'step' => 5,
                    ],
                    'vh'  => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 400,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'content_width',
            [
                'label'      => esc_html__( 'Content Width', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px','%'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 3000,
                        'step' => 5,
                    ],
                    '%'  => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default'    => [
                    'unit' => '%',
                    'size' => 50,
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header .el-page-content' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'breadcrumb',
            [
                'label'        => esc_html__( 'Breadcrumb', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'bottom_border',
            [
                'label'        => esc_html__( 'Bottom Border', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'overlay',
            [
                'label'        => esc_html__( 'Overlay', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Show', 'redias-core' ),
                'label_off'    => esc_html__( 'Hide', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'no',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Content Section
     *
     * @return void
     */
    protected function content_section() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Content', 'redias-core' ),
            ]
        );

        $this->add_control(
            'sub_heading',
            [
                'label'       => __( 'Sub Heading', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'label_block'     => true,
                'default'     => '',
                'placeholder' => esc_html__( 'Text...', 'redias-core' ),
            ]
        );

        $this->add_control(
            'sub_h_tag',
            [
                'label'   => esc_html__( 'Sub Heading Tag', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1'  => esc_html__( 'H1', 'redias-core' ),
                    'h2'  => esc_html__( 'H2', 'redias-core' ),
                    'h3'  => esc_html__( 'H3', 'redias-core' ),
                    'h4'  => esc_html__( 'H4', 'redias-core' ),
                    'h5'  => esc_html__( 'H5', 'redias-core' ),
                    'h6'  => esc_html__( 'H6', 'redias-core' ),
                    'div' => esc_html__( 'DIV', 'redias-core' ),
                ],
                'condition'    => [
                    'sub_heading!'    => ''
                ],
            ]
        );

        $this->add_control(
            'heading_sec',
            [
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'heading_type',
            [
                'label'   => esc_html__( 'Heading Type', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'page_title',
                'options' => [
                    'page_title'  => esc_html__( 'Page Title', 'redias-core' ),
                    'custom' => esc_html__( 'Custom', 'redias-core' ),
                ],
            ]
        );

        $this->add_control(
            'heading',
            [
                'label'       => esc_html__( 'Heading Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'rows'        => 4,
                'default'     => '',
                'placeholder' => esc_html__( 'Heading...', 'redias-core' ),
                'condition'    => [
                    'heading_type'    => 'custom',
                ],
            ]
        );

        $this->add_control(
            'h_tag',
            [
                'label'   => esc_html__( 'Heading Tag', 'redias-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'h2',
                'options' => [
                    'h1'  => esc_html__( 'H1', 'redias-core' ),
                    'h2'  => esc_html__( 'H2', 'redias-core' ),
                    'h3'  => esc_html__( 'H3', 'redias-core' ),
                    'h4'  => esc_html__( 'H4', 'redias-core' ),
                    'h5'  => esc_html__( 'H5', 'redias-core' ),
                    'h6'  => esc_html__( 'H6', 'redias-core' ),
                    'div' => esc_html__( 'DIV', 'redias-core' ),
                ],
            ]
        );
        
        $this->add_control(
            'description',
            [
                'label'       => esc_html__( 'Description', 'redias-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'rows'        => 5,
                'separator' => 'before',
                'default'     => '',
                'placeholder' => esc_html__( 'Description...', 'redias-core' ),
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Background Style
     *
     * @return void
     */
    protected function background_style() {
        
        $this->start_controls_section(
            'background_style_section',
            [
                'label' => esc_html__( 'Background', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'featured_img',
            [
                'label'        => esc_html__( 'Featured Image', 'redias-core' ),
                'description'  => esc_html__( 'Use background image from featured image.', 'redias-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'Yes', 'redias-core' ),
                'label_off'    => esc_html__( 'No', 'redias-core' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );
        
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'img_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .el-page-header'
            ]
        );

        $this->add_control(
            'image_blend_mode',
            [
                'label' => esc_html__( 'Blend Mode', 'redias-core' ),
                'type' => Controls_Manager::SELECT,
                'separator' => 'before',
                'default' => 'inherit',
                'options' => [
                    'inherit' => esc_html__( 'Normal', 'redias-core' ),
                    'multiply' => 'Multiply',
                    'screen' => 'Screen',
                    'overlay' => 'Overlay',
                    'darken' => 'Darken',
                    'lighten' => 'Lighten',
                    'color-dodge' => 'Color Dodge',
                    'saturation' => 'Saturation',
                    'color' => 'Color',
                    'difference' => 'Difference',
                    'exclusion' => 'Exclusion',
                    'hue' => 'Hue',
                    'luminosity' => 'Luminosity',
                ],
                'selectors' => [
                    '{{WRAPPER}} .el-page-header' => 'background-blend-mode: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'overlay_heading',
            [
                'label' => esc_html__( 'Overlay', 'redias-core' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition'    => [
                   'overlay'    => 'yes'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'ov_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .el-page-header .overlay',
                'condition'    => [
                    'overlay'    => 'yes'
                 ],
            ]
        );

        $this->add_responsive_control(
            'ov_opacity',
            [
                'label'      => esc_html__( 'Opacity', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 1,
                        'step' => 0.1,
                    ]
                ],
                'default'    => [
                    'unit' => 'px',
                    'size' => 0.5,
                ],
                'separator' => 'before',
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header .overlay' => 'opacity: {{SIZE}};',
                ],
                'condition'    => [
                    'overlay'    => 'yes'
                 ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Sub Heading Style
     *
     * @return void
     */
    protected function sub_heading_style() {
        
        $this->start_controls_section(
            'sub_heading_style',
            [
                'label' => esc_html__( 'Sub Heading', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'sub_heading!'    => ''
                ],
            ]
        );
        
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'sub_heading_bg',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'exclude'  => ['image'],
                'selector' => '{{WRAPPER}} .el-page-header .el-page-content .sub-title',
                'condition'    => [
                    'sub_heading!'  => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'sub_heading_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-page-header .el-page-content .sub-title',
                'condition'    => [
                    'sub_heading!'  => ''
                ],
            ]
        );

        $this->add_control(
            'sub_heading_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-page-header .el-page-content .sub-title' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'sub_heading!'  => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'sub_heading_box_shadow',
                'selector' => '{{WRAPPER}} .el-page-header .el-page-content .sub-title',
                'condition'    => [
                    'sub_heading!'  => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'sub_heading_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-page-header .el-page-content .sub-title',
                'condition'    => [
                    'sub_heading!'  => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header .el-page-content .sub-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'sub_heading!'  => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header .el-page-content .sub-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'sub_heading!'  => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header .el-page-content .sub-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'sub_heading!'  => ''
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Heading Style
     *
     * @return void
     */
    protected function heading_style() {
        
        $this->start_controls_section(
            'heading_style',
            [
                'label' => esc_html__( 'Heading', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'heading_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-page-header .el-page-content .title',
            ]
        );

        $this->add_group_control(
            Foreground::get_type(),
            [
                'name'     => 'heading_color',
                'label'    => esc_html__( 'Heading Color', 'redias-core' ),
                'types'    => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .el-page-header .el-page-content .title',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'heading_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-page-header .el-page-content .title',
            ]
        );

        $this->add_responsive_control(
            'heading_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header .el-page-content .title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header .el-page-content .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header .el-page-content .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Description Style
     *
     * @return void
     */
    protected function description_style() {
        
        $this->start_controls_section(
            'description_style',
            [
                'label' => esc_html__( 'Description', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'description!'    => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'desc_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-page-header .el-page-content p',
                'condition'    => [
                    'description!'  => ''
                ],
            ]
        );

        $this->add_control(
            'desc_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-page-header .el-page-content p' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'description!'  => ''
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'desc_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-page-header .el-page-content p',
                'condition'    => [
                    'description!'  => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header .el-page-content p' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'description!'  => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header .el-page-content p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'description!'  => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'desc_margin',
            [
                'label'      => esc_html__( 'Margin', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-page-header .el-page-content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'description!'  => ''
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Shape Style
     *
     * @return void
     */
    protected function shape_style() {
        
        $this->start_controls_section(
            'shape_style_section',
            [
                'label' => esc_html__( 'Shape', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'breadcrumb!'    => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
			'shape_size',
			[
				'label' => esc_html__( 'Shape Size', 'textdomain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1
					],
				],
				'selectors' => [
					'{{WRAPPER}} .page-header-shape .shape' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .page-header-shape .shape.center.back' => 'height: calc({{SIZE}}{{UNIT}} - 20px);',
				],
                'condition'    => [
                    'breadcrumb!'    => 'yes'
                ],
			]
		);

        $this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'shape_colors',
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .page-header-shape .shape',
                'condition'    => [
                    'breadcrumb!'    => 'yes'
                ],
			]
		);
        
        $this->end_controls_section();

    }

    /**
     * Breadcrumb Style
     *
     * @return void
     */
    protected function breadcrumb_style() {
        
        $this->start_controls_section(
            'breadcrumb_style',
            [
                'label' => esc_html__( 'Breadcrumb', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'bc_spacebetween',
            [
                'label'      => esc_html__( 'Space Between', 'redias-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min'  => 0,
                        'max'  => 50,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .el-breadcrumbs .sep' => 'margin: 0 {{SIZE}}{{UNIT}};'
                ],
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_control(
            'home_text',
            [
                'label'       => esc_html__( 'Home Text', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Home', 'redias-core' ),
                'placeholder' => esc_html__( 'Text...', 'redias-core' ),
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_control(
            'title_length',
            [
                'label'   => esc_html__( 'Heading Length', 'redias-core' ),
                'type'    => Controls_Manager::NUMBER,
                'min'     => 10,
                'max'     => 150,
                'step'    => 1,
                'default' => 32,
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'     => 'bc_background',
                'label'    => esc_html__( 'Background', 'redias-core' ),
                'types'    => ['gradient'],
                'selector' => '{{WRAPPER}} .el-breadcrumbs',
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'breadcrumb_typography',
                'label'    => esc_html__( 'Typography', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-breadcrumbs li a, {{WRAPPER}} .el-breadcrumbs li',
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_control(
            'breadcrumb_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-breadcrumbs li a' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_control(
            'breadcrumb_active_color',
            [
                'label'     => esc_html__( 'Active Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-breadcrumbs li' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_control(
            'breadcrumb_hover_color',
            [
                'label'     => esc_html__( 'Hover Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-breadcrumbs li a:hover' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_control(
            'breadcrumb_sep_color',
            [
                'label'     => esc_html__( 'Separator Color', 'redias-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .el-breadcrumbs .sep' => 'color: {{VALUE}}',
                ],
                'condition'    => [
                    'breadcrumb'    => 'yes'
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'bc_border',
                'label'    => esc_html__( 'Border', 'redias-core' ),
                'selector' => '{{WRAPPER}} .el-breadcrumbs',
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'bc_box_shadow',
                'selector' => '{{WRAPPER}} .el-breadcrumbs',
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'bc_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-breadcrumbs' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'bc_padding',
            [
                'label'      => esc_html__( 'Padding', 'redias-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .el-breadcrumbs' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition'    => [
                    'breadcrumb'    => 'yes',
                ],
            ]
        );
        
        $this->end_controls_section();

    }

    /**
     * Bottom Border Style
     *
     * @return void
     */
    protected function bottom_border_style() {
        
        $this->start_controls_section(
            'bd_bottom_style_section',
            [
                'label' => esc_html__( 'Bottom Border', 'redias-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'bottom_border'    => 'yes'
                ],
            ]
        );

        $this->add_responsive_control(
			'bottom_bd_size',
			[
				'label' => esc_html__( 'Border Size', 'textdomain' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1
					],
				],
				'selectors' => [
					'{{WRAPPER}} .el-page-header.bottom-border:before' => 'height: {{SIZE}}{{UNIT}};'
				],
                'condition'    => [
                    'bottom_border'    => 'yes'
                ],
			]
		);

        $this->add_control(
			'bottom_bd_heading',
			[
				'label' => esc_html__( 'Border Color', 'textdomain' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition'    => [
                    'bottom_border'    => 'yes'
                ],
			]
		);

        $this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'bottom_bd_colors',
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .page-header-shape .shape',
                'condition'    => [
                    'bottom_border'    => 'yes'
                ],
			]
		);
        
        $this->end_controls_section();

    }

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        $bottom_border = 'yes' === $settings['bottom_border'] ? 'bottom-border' : '';
        $this->add_render_attribute(
            'wrapper', 
            [ 'class' => [ 'el-page-header', $bottom_border ] ]
        );
        if( 'yes' === $settings['featured_img'] ) {
            $thumbnail_id = get_post_thumbnail_id(get_the_ID());
            if( ! empty( $thumbnail_id ) ) {
                $thumbnail_src = wp_get_attachment_image_src( $thumbnail_id, 'full' );
                $thumbnail_url = isset($thumbnail_src[0]) ? $thumbnail_src[0] : '';
                if( ! empty( $thumbnail_url ) ) {
                    $this->add_render_attribute(
                        'wrapper',
                        [ 
                            'style' => 'background-image: url('. esc_url( $thumbnail_url ) .')',
                        ]
                    );
                }
            }
        }
        $this->add_render_attribute( 'sub_heading', [ 'class' => 'sub-title' ] );
        $this->add_render_attribute( 'heading', [ 'class' => 'title' ] );
        $this->add_inline_editing_attributes( 'sub_heading', 'none' );
        $this->add_inline_editing_attributes( 'description', 'none' );
        if( 'custom' === $settings['heading_type'] ) {
            $this->add_inline_editing_attributes( 'heading', 'none' );
        }
        $breadcrumb_txt = '';
        if( 'page_title' === $settings['heading_type'] ) {
            $breadcrumb_txt = get_the_title( '', get_the_ID() );
        }else{
            $breadcrumb_txt = ! empty( $settings['heading'] ) ? $settings['heading'] : '';
        }
        ?>
        <div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
            <?php
                if( 'yes' === $settings['overlay'] ) {
                    echo '<div class="overlay"></div>';
                }
            ?>
            <div class="container">
                <div class="el-page-content">
                    <?php if( ! empty( $settings['sub_heading'] ) ) : ?>
                    <<?php echo esc_attr( $settings['sub_h_tag'] ); ?> <?php echo $this->get_render_attribute_string( 'sub_heading' ); ?>><?php echo Helper::kses_basic( $settings['sub_heading'] ); ?></<?php echo esc_attr( $settings['sub_h_tag'] ); ?>>
                    <?php endif; ?>
                    <?php if( 'page_title' === $settings['heading_type'] ) : ?>
                    <<?php echo esc_attr( $settings['h_tag'] ); ?> <?php echo $this->get_render_attribute_string( 'heading' ); ?>><?php the_title(); ?></<?php echo esc_attr( $settings['h_tag'] ); ?>>
                    <?php else : ?>
                        <?php if( ! empty( $settings['heading'] ) ) : ?>
                        <<?php echo esc_attr( $settings['h_tag'] ); ?> <?php echo $this->get_render_attribute_string( 'heading' ); ?>><?php echo Helper::kses_basic( $settings['heading'] ); ?></<?php echo esc_attr( $settings['h_tag'] ); ?>>
                        <?php endif; ?>
                    <?php endif; ?>
                    <?php if( ! empty( $settings['description'] ) ) : ?>
                        <p <?php echo $this->get_render_attribute_string( 'description' ); ?>><?php echo Helper::kses_basic( $settings['description'] ); ?></p>
                    <?php endif; ?>
                </div>
                <?php if( 'yes' === $settings['breadcrumb'] ) : 
                    $bc_home_txt = ! empty( $settings['home_text'] ) ? $settings['home_text'] : esc_html__( 'Home', 'redias-core' );
                ?>
                <ul class="el-breadcrumbs">
                    <li><a href="<?php echo esc_url(home_url( '/')) ?>"><?php echo esc_html( $bc_home_txt ); ?></a><span class="sep">|</span></li>
                    <li><?php Helper::limit_latter( $breadcrumb_txt, $settings['title_length'], '...'); ?></li> 
                </ul>
                <?php endif; ?>
            </div>
            <?php
            if( 'yes' != $settings['breadcrumb'] ) {
                echo '<div class="page-header-shape"><div class="shape"></div><div class="shape center"></div><div class="shape center back"></div><div class="shape right"></div></div>';
            }
            ?>
        </div>
        <?php
    }

}