<?php
/**
 * Animated Text
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Tabs;

use RediasCore\Classes\Helper;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'redias-tabs';
	}

	/**
	 * Get widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Tabs', 'redias-core' );
	}

	public function get_custom_help_url() {
		return 'https://dynamiclayers.net';
	}

	/**
	 * Get widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'redias-icon eicon-tabs';
	}

	public function get_categories() {
		return ['redias-core'];
	}

	public function get_keywords() {
		return ['tabs', 'toggle', 'redias'];
	}

	public function get_script_depends() {
		return ['redias-el-script'];
	}

	public function get_style_depends() {
		return ['redias-tabs'];
	}

	/**
	 * Register controls
	 */
	protected function register_controls() {

		$this->section_tabs_content();
		$this->section_tabs_options();
		$this->style_tabs_title();
		$this->style_tabs_icon();
		$this->style_tabs_content();

	}

	/**
	 * Tabs Content Controls
	 *
	 * @return void
	 */
	protected function section_tabs_content() {

		$this->start_controls_section(
			'section_tabs',
			[
				'label' => esc_html__( 'Tabs', 'redias-core' ),
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'title',
			[
				'type'        => Controls_Manager::TEXT,
				'label'       => esc_html__( 'Title', 'redias-core' ),
				'default'     => esc_html__( 'Tab Title', 'redias-core' ),
				'placeholder' => esc_html__( 'Type Tab Title', 'redias-core' ),
				'dynamic'     => [
					'active' => true,
				],
			]
		);

		$repeater->add_control(
			'icon',
			[
				'type'       => Controls_Manager::ICONS,
				'label'      => esc_html__( 'Icon', 'redias-core' ),
				'show_label' => false,
			]
		);

		$repeater->add_control(
			'source',
			[
				'type'      => Controls_Manager::SELECT,
				'label'     => esc_html__( 'Content Source', 'redias-core' ),
				'default'   => 'editor',
				'separator' => 'before',
				'options'   => [
					'editor'   => esc_html__( 'Editor', 'redias-core' ),
					'template' => esc_html__( 'Template', 'redias-core' ),
				],
			]
		);

		$repeater->add_control(
			'editor',
			[
				'label'      => esc_html__( 'Content Editor', 'redias-core' ),
				'show_label' => false,
				'type'       => Controls_Manager::WYSIWYG,
				'condition'  => [
					'source' => 'editor',
				],
				'dynamic'    => [
					'active' => true,
				],
			]
		);

		$repeater->add_control(
			'template',
			[
				'label'       => esc_html__( 'Section Template', 'redias-core' ),
				'placeholder' => esc_html__( 'Select a section template for as tab content', 'redias-core' ),
				'description' => sprintf( __( 'Wondering what is section template or need to create one? Please click %1$shere%2$s ', 'redias-core' ),
					'<a target="_blank" href="' . esc_url( admin_url( '/edit.php?post_type=elementor_library&tabs_group=library&elementor_library_type=section' ) ) . '">',
					'</a>'
				),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'options'     => Helper::get_section_templates(),
				'condition'   => [
					'source' => 'template',
				],
			]
		);

		$this->add_control(
			'tabs',
			[
				'show_label'  => false,
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'title_field' => '{{title}}',
				'default'     => [
					[
						'title'  => 'Tab 1',
						'source' => 'editor',
						'editor' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore <br><br>et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.',
					],
					[
						'title'  => 'Tab 2',
						'source' => 'editor',
						'editor' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore <br><br>et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.',
					],
				],
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Tabs Options Controls
	 *
	 * @return void
	 */
	protected function section_tabs_options() {

		$this->start_controls_section(
			'section_options',
			[
				'label' => esc_html__( 'Options', 'redias-core' ),
			]
		);

		$this->add_control(
			'_heading_tab_title',
			[
				'label' => esc_html__( 'Tab Title', 'redias-core' ),
				'type'  => Controls_Manager::HEADING,
			]
		);

		$this->add_control(
			'nav_position',
			[
				'type'           => Controls_Manager::CHOOSE,
				'label'          => esc_html__( 'Position', 'redias-core' ),
				'description'    => esc_html__( 'Only applicable for desktop', 'redias-core' ),
				'default'        => 'top',
				'toggle'         => false,
				'options'        => [
					'left'  => [
						'title' => esc_html__( 'Left', 'redias-core' ),
						'icon'  => 'eicon-h-align-left',
					],
					'top'   => [
						'title' => esc_html__( 'Top', 'redias-core' ),
						'icon'  => 'eicon-v-align-top',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'redias-core' ),
						'icon'  => 'eicon-h-align-right',
					],
				],
				'style_transfer' => true,
			]
		);

		$this->add_control(
			'nav_align_x',
			[
				'type'                 => Controls_Manager::CHOOSE,
				'label'                => esc_html__( 'Alignment', 'redias-core' ),
				'default'              => 'x-left',
				'toggle'               => false,
				'options'              => [
					'x-left'    => [
						'title' => esc_html__( 'Left', 'redias-core' ),
						'icon'  => 'eicon-h-align-left',
					],
					'x-center'  => [
						'title' => esc_html__( 'Center', 'redias-core' ),
						'icon'  => 'eicon-h-align-center',
					],
					'x-justify' => [
						'title' => esc_html__( 'Stretch', 'redias-core' ),
						'icon'  => 'eicon-h-align-stretch',
					],
					'x-right'   => [
						'title' => esc_html__( 'Right', 'redias-core' ),
						'icon'  => 'eicon-h-align-right',
					],
				],
				'selectors'            => [
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--nav-top > .dl-tabs__nav' => 'justify-content: {{VALUE}};',
				],
				'selectors_dictionary' => [
					'x-left'    => 'flex-start',
					'x-right'   => 'flex-end',
					'x-center'  => 'center',
					'x-justify' => 'space-evenly',
				],
				'condition'            => [
					'nav_position' => ['top', 'bottom'],
				],
				'style_transfer'       => true,
				'render_type'          => 'template',
			]
		);

		$this->add_control(
			'nav_align_y',
			[
				'type'                 => Controls_Manager::CHOOSE,
				'label'                => esc_html__( 'Alignment', 'redias-core' ),
				'default'              => 'y-top',
				'toggle'               => false,
				'options'              => [
					'y-top'    => [
						'title' => esc_html__( 'Top', 'redias-core' ),
						'icon'  => 'eicon-v-align-top',
					],
					'y-center' => [
						'title' => esc_html__( 'Center', 'redias-core' ),
						'icon'  => 'eicon-v-align-middle',
					],
					'y-bottom' => [
						'title' => esc_html__( 'Right', 'redias-core' ),
						'icon'  => 'eicon-v-align-bottom',
					],
				],
				'selectors'            => [
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--nav-left > .dl-tabs__nav'  => 'justify-content: {{VALUE}};',
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--nav-right > .dl-tabs__nav' => 'justify-content: {{VALUE}};',
				],
				'selectors_dictionary' => [
					'y-top'    => 'flex-start',
					'y-center' => 'center',
					'y-bottom' => 'flex-end',
				],
				'condition'            => [
					'nav_position' => ['left', 'right'],
				],
				'style_transfer'       => true,
			]
		);

		$this->add_control(
			'nav_text_align',
			[
				'type'                 => Controls_Manager::CHOOSE,
				'label'                => esc_html__( 'Text Alignment', 'redias-core' ),
				'default'              => 'center',
				'toggle'               => false,
				'options'              => [
					'left'   => [
						'title' => esc_html__( 'Left', 'redias-core' ),
						'icon'  => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'redias-core' ),
						'icon'  => 'eicon-text-align-center',
					],
					'right'  => [
						'title' => esc_html__( 'Right', 'redias-core' ),
						'icon'  => 'eicon-text-align-right',
					],
				],
				'selectors'            => [
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab__title--desktop' => 'justify-content: {{VALUE}};',
				],
				'selectors_dictionary' => [
					'left'   => 'flex-start',
					'center' => 'center',
					'right'  => 'flex-end',
				],
				'style_transfer'       => true,
			]
		);

		$this->add_control(
			'_heading_tab_icon',
			[
				'label'     => esc_html__( 'Tab Icon', 'redias-core' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'nav_icon_position',
			[
				'type'           => Controls_Manager::CHOOSE,
				'label'          => esc_html__( 'Position', 'redias-core' ),
				'default'        => 'left',
				'toggle'         => false,
				'options'        => [
					'left'   => [
						'title' => esc_html__( 'Left', 'redias-core' ),
						'icon'  => 'eicon-h-align-left',
					],
					'top'    => [
						'title' => esc_html__( 'Top', 'redias-core' ),
						'icon'  => 'eicon-v-align-top',
					],
					'bottom' => [
						'title' => esc_html__( 'Bottom', 'redias-core' ),
						'icon'  => 'eicon-v-align-bottom',
					],
					'right'  => [
						'title' => esc_html__( 'Right', 'redias-core' ),
						'icon'  => 'eicon-h-align-right',
					],
				],
				'style_transfer' => true,
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Tabs Title Style
	 *
	 * @return void
	 */
	protected function style_tabs_title() {

		$this->start_controls_section(
			'section_style_tab_title',
			[
				'label' => esc_html__( 'Tab Title', 'redias-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'nav_margin_x',
			[
				'label'     => esc_html__( 'Horizontal Margin (px)', 'redias-core' ),
				'type'      => Controls_Manager::NUMBER,
				'step'      => 'any',
				'selectors' => [
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--nav-top > .dl-tabs__nav > .dl-tab__title:not(:last-child)'    => 'margin-right: {{VALUE}}px;',
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--nav-bottom > .dl-tabs__nav > .dl-tab__title:not(:last-child)' => 'margin-right: {{VALUE}}px;',
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--nav-left > .dl-tabs__nav > .dl-tab__title'                    => 'margin-right: {{VALUE}}px;',
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--nav-right > .dl-tabs__nav > .dl-tab__title'                   => 'margin-left: {{VALUE}}px;',
				],
			]
		);

		$this->add_control(
			'nav_margin_y',
			[
				'label'     => esc_html__( 'Vertical Margin (px)', 'redias-core' ),
				'type'      => Controls_Manager::NUMBER,
				'step'      => 'any',
				'selectors' => [
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--nav-top > .dl-tabs__nav > .dl-tab__title'                    => 'margin-bottom: {{VALUE}}px;',
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--nav-bottom > .dl-tabs__nav > .dl-tab__title'                 => 'margin-top: {{VALUE}}px;',
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--nav-left > .dl-tabs__nav > .dl-tab__title:not(:last-child)'  => 'margin-bottom: {{VALUE}}px;',
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--nav-right > .dl-tabs__nav > .dl-tab__title:not(:last-child)' => 'margin-bottom: {{VALUE}}px;',
				],
			]
		);

		$this->add_responsive_control(
			'nav_padding',
			[
				'label'      => esc_html__( 'Padding', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors'  => [
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab__title'     => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'nav_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%'],
				'selectors'  => [
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab__title'     => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'nav_typography',
				'selector' => '{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab__title, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__title',
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name'     => 'nav_text_shadow',
				'label'    => esc_html__( 'Text Shadow', 'redias-core' ),
				'selector' => '{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab__title, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__title',
			]
		);

		$this->start_controls_tabs( '_tab_nav_stats' );

		$this->start_controls_tab(
			'_tab_nav_normal',
			[
				'label' => esc_html__( 'Normal', 'redias-core' ),
			]
		);

		$this->add_control(
			'nav_border_style',
			[
				'label'       => esc_html__( 'Border Style', 'redias-core' ),
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'none'   => esc_html__( 'None', 'redias-core' ),
					'solid'  => esc_html__( 'Solid', 'redias-core' ),
					'double' => esc_html__( 'Double', 'redias-core' ),
					'dotted' => esc_html__( 'Dotted', 'redias-core' ),
					'dashed' => esc_html__( 'Dashed', 'redias-core' ),
				],
				'default'     => 'none',
				'render_type' => 'ui',
			]
		);
		
		$this->add_control(
			'nav_border_width',
			[
				'label'       => esc_html__( 'Border Width', 'redias-core' ),
				'type'        => Controls_Manager::DIMENSIONS,
				'size_units'  => ['px'],
				'condition'   => [
					'nav_border_style!' => 'none',
				],
				'render_type' => 'ui',
			]
		);

		$this->add_control(
			'nav_border_color',
			[
				'label'     => esc_html__( 'Border Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'nav_border_style!' => 'none',
				],
				'selectors' => [
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__title, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab__title' => 'border-style: {{nav_border_style.VALUE}}; border-color: {{VALUE}};',
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab__title'                                                                   => 'border-width: {{nav_border_width.TOP}}px {{nav_border_width.RIGHT}}px {{nav_border_width.BOTTOM}}px {{nav_border_width.LEFT}}px;',
				]
			]
		);

		$this->add_control(
			'nav_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav .dl-tab__title-text, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav .dl-tab__title-icon, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content .dl-tab__title-text, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content .dl-tab__title-icon' => 'color: {{VALUE}};',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'nav_bg',
				'types'    => ['classic', 'gradient'],
				'exclude'  => ['image'],
				'selector' => '{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav .dl-tab__title, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content .dl-tab__title',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'_tab_nav_active',
			[
				'label' => esc_html__( 'Active', 'redias-core' ),
			]
		);

		$this->add_control(
			'nav_active_border_style',
			[
				'label'       => esc_html__( 'Border Style', 'redias-core' ),
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'none'   => esc_html__( 'None', 'redias-core' ),
					'solid'  => esc_html__( 'Solid', 'redias-core' ),
					'double' => esc_html__( 'Double', 'redias-core' ),
					'dotted' => esc_html__( 'Dotted', 'redias-core' ),
					'dashed' => esc_html__( 'Dashed', 'redias-core' ),
				],
				'default'     => 'none',
				'render_type' => 'ui',
			]
		);

		$this->add_control(
			'nav_active_border_width',
			[
				'label'       => esc_html__( 'Border Width', 'redias-core' ),
				'type'        => Controls_Manager::DIMENSIONS,
				'size_units'  => ['px'],
				'condition'   => [
					'nav_active_border_style!' => 'none',
				],
				'render_type' => 'ui',
			]
		);

		$this->add_control(
			'nav_active_border_color',
			[
				'label'     => esc_html__( 'Border Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'nav_active_border_style!' => 'none',
				],
				'selectors' => [
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__title.dl-tab--active, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab__title.dl-tab--active' => 'border-style: {{nav_active_border_style.VALUE}}; border-color: {{VALUE}};',
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab__title.dl-tab--active'                                                                                     => 'border-width: {{nav_active_border_width.TOP}}px {{nav_active_border_width.RIGHT}}px {{nav_active_border_width.BOTTOM}}px {{nav_active_border_width.LEFT}}px;',
				]
			]
		);

		$this->add_control(
			'nav_active_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab--active .dl-tab__title-text, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab--active .dl-tab__title-icon, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab--active .dl-tab__title-text, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab--active .dl-tab__title-icon' => 'color: {{VALUE}};',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'nav_active_bg',
				'types'    => ['classic', 'gradient'],
				'exclude'  => ['image'],
				'selector' => '{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav > .dl-tab__title.dl-tab--active, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__title.dl-tab--active',
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

	}

	/**
	 * Tabs Icon Style
	 *
	 * @return void
	 */
	protected function style_tabs_icon() {

		$this->start_controls_section(
			'section_style_tab_icon',
			[
				'label' => esc_html__( 'Tab Icon', 'redias-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'nav_icon_spacing',
			[
				'label'      => esc_html__( 'Spacing', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors'  => [
					'{{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--icon-left > .dl-tabs__nav .dl-tab__title-icon, {{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--icon-left > .dl-tabs__content .dl-tab__title-icon'     => 'margin-right: {{SIZE}}px;',
					'{{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--icon-right > .dl-tabs__nav .dl-tab__title-icon, {{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--icon-right > .dl-tabs__content .dl-tab__title-icon'   => 'margin-left: {{SIZE}}px;',
					'{{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--icon-top > .dl-tabs__nav .dl-tab__title-icon, {{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--icon-top > .dl-tabs__content .dl-tab__title-icon'       => 'margin-bottom: {{SIZE}}px;',
					'{{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--icon-bottom > .dl-tabs__nav .dl-tab__title-icon, {{WRAPPER}} .dl-tabs-{{ID}}.dl-tabs--icon-bottom > .dl-tabs__content .dl-tab__title-icon' => 'margin-top: {{SIZE}}px;',
				],
			]
		);

		$this->add_control(
			'nav_icon_size',
			[
				'label'      => esc_html__( 'Size', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'selectors'  => [
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__nav .dl-tab__title-icon, {{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content .dl-tab__title-icon' => 'font-size: {{SIZE}}px;',
				],
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Tabs Content Style
	 *
	 * @return void
	 */
	protected function style_tabs_content() {

		$this->start_controls_section(
			'section_style_tab_content',
			[
				'label' => esc_html__( 'Tab Content', 'redias-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'content_padding',
			[
				'label'      => esc_html__( 'Padding', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors'  => [
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'content_border_style',
			[
				'label'       => esc_html__( 'Border Style', 'redias-core' ),
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'none'   => esc_html__( 'None', 'redias-core' ),
					'solid'  => esc_html__( 'Solid', 'redias-core' ),
					'double' => esc_html__( 'Double', 'redias-core' ),
					'dotted' => esc_html__( 'Dotted', 'redias-core' ),
					'dashed' => esc_html__( 'Dashed', 'redias-core' ),
				],
				'default'     => 'none',
				'render_type' => 'ui',
			]
		);

		$this->add_control(
			'content_border_width',
			[
				'label'       => esc_html__( 'Border Width', 'redias-core' ),
				'type'        => Controls_Manager::DIMENSIONS,
				'size_units'  => ['px'],
				'condition'   => [
					'content_border_style!' => 'none',
				],
				'render_type' => 'ui',
			]
		);

		$this->add_control(
			'content_border_color',
			[
				'label'     => esc_html__( 'Border Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'content_border_style!' => 'none',
				],
				'selectors' => [
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__content'          => 'border-style: {{content_border_style.VALUE}}; border-color: {{VALUE}};',
					'(tablet+){{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__content' => 'border-width: {{content_border_width.TOP}}px {{content_border_width.RIGHT}}px {{content_border_width.BOTTOM}}px {{content_border_width.LEFT}}px;',
				]
			]
		);

		$this->add_control(
			'content_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%'],
				'selectors'  => [
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'content_typography',
				'selector' => '{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__content',
			]
		);

		$this->add_control(
			'content_color',
			[
				'label'     => esc_html__( 'Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__content' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'content_bg',
				'types'    => ['classic', 'gradient'],
				'selector' => '{{WRAPPER}} .dl-tabs-{{ID}} > .dl-tabs__content > .dl-tab__content',
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Render Content
	 *
	 * @return void
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		$tabs = (array) $settings['tabs'];
		$id_int = substr( $this->get_id_int(), 0, 3 );

		$this->add_render_attribute( 'tabs_wrapper', 'class', [
			'dl-tabs-' . $this->get_id(),
			'dl-tabs',
			'dl-tabs--nav-' . $settings['nav_position'],
			in_array( $settings['nav_position'], ['top', 'bottom'] ) ? 'dl-tabs--nav-' . $settings['nav_align_x'] : '',
			in_array( $settings['nav_position'], ['left', 'right'] ) ? 'dl-tabs--nav-' . $settings['nav_align_y'] : '',
			'dl-tabs--icon-' . $settings['nav_icon_position'],
		] );

		$this->add_render_attribute( 'tabs_wrapper', 'role', 'tablist' );
		?>
		<div <?php $this->print_render_attribute_string( 'tabs_wrapper' ); ?>>
			<div class="dl-tabs__nav">
				<?php
				foreach ( $tabs as $index => $item ) :
					$tab_count = $index + 1;

					$tab_title_setting_key = $this->get_repeater_setting_key( 'title', 'tabs', $index );
					$tab_content_id = 'dl-tab__content-' . $id_int . $tab_count;

					$this->add_render_attribute( $tab_title_setting_key, [
						'id' => 'dl-tab-title-' . $id_int . $tab_count,
						'class' => [ 'dl-tab__title', 'dl-tab__title--desktop', 'elementor-repeater-item-' . $item['_id'] ],
						'data-tab' => $tab_count,
						'role' => 'tab',
						'aria-controls' => $tab_content_id,
					] );
					?>
					<div <?php echo $this->get_render_attribute_string( $tab_title_setting_key ); ?>>
						<?php if ( ! empty( $item['icon'] ) && ! empty( $item['icon']['value'] ) ) : ?>
						<span class="dl-tab__title-icon"><?php Helper::render_icon( $item, false, 'icon' ); ?></span>
						<?php endif; ?>
						<span class="dl-tab__title-text"><?php echo Helper::kses_basic( $item['title'] ); ?></span></div>
				<?php endforeach; ?>
			</div>
			<div class="dl-tabs__content">
				<?php
				foreach ( $tabs as $index => $item ) :
					$tab_count = $index + 1;

					if ( $item['source'] === 'editor' ) {
						$tab_content_setting_key = $this->get_repeater_setting_key( 'editor', 'tabs', $index );
						$this->add_inline_editing_attributes( $tab_content_setting_key, 'advanced' );
					} else {
						$tab_content_setting_key = $this->get_repeater_setting_key( 'section', 'tabs', $index );
					}

					$tab_title_mobile_setting_key = $this->get_repeater_setting_key( 'tab_title_mobile', 'tabs', $tab_count );

					$this->add_render_attribute( $tab_content_setting_key, [
						'id' => 'dl-tab-content-' . $id_int . $tab_count,
						'class' => [ 'dl-tab__content', 'dl-clearfix', 'elementor-repeater-item-' . $item['_id'] ],
						'data-tab' => $tab_count,
						'role' => 'tabpanel',
						'aria-labelledby' => 'dl-tab-title-' . $id_int . $tab_count,
					] );

					$this->add_render_attribute( $tab_title_mobile_setting_key, [
						'class' => [ 'dl-tab__title', 'dl-tab__title--mobile', 'elementor-repeater-item-' . $item['_id'] ],
						'data-tab' => $tab_count,
						'role' => 'tab',
					] );
					?>
					<div <?php echo $this->get_render_attribute_string( $tab_title_mobile_setting_key ); ?>>
						<?php if ( ! empty( $item['icon'] ) && ! empty( $item['icon']['value'] ) ) : ?>
						<span class="dl-tab__title-icon"><?php Helper::render_icon( $item, false, 'icon' ); ?></span>
						<?php endif; ?>
						<span class="dl-tab__title-text"><?php echo Helper::kses_basic( $item['title'] ); ?></span>
					</div>
					<div <?php echo $this->get_render_attribute_string( $tab_content_setting_key ); ?>>
						<?php
						if ( $item['source'] === 'editor' ) :
							echo $this->parse_text_editor( $item['editor'] );
						elseif ( $item['source'] === 'template' && $item['template'] ) :
							echo Helper::elementor()->frontend->get_builder_content_for_display( $item['template'] );
						endif;
						?>
					</div>
				<?php endforeach; ?>
			</div>
		</div>
        <?php

	}

}