<?php
/**
 * Testimonials
 *
 * @package RediasCore
 */
namespace RediasCore\Elementor\Widgets\Testimonials;

use RediasCore\Classes\Helper;
use RediasCore\Traits\CarouselControls;
use Elementor\Controls_Manager;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Repeater;
use Elementor\Widget_Base;

defined( 'ABSPATH' ) || die();

class Widget extends Widget_Base {

    use CarouselControls;

    /**
     * Get widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'redias-testimonials';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Testimonials', 'redias-core' );
    }

    public function get_custom_help_url() {
        return 'https://dynamiclayers.net';
    }

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'redias-icon eicon-testimonial-carousel';
    }

    public function get_categories() {
        return ['redias-core'];
    }

    public function get_keywords() {
        return [ 'testimonials', 'reviews', 'client reviews', 'testimonials carousel', 'redias' ];
    }

    public function get_style_depends() {
        return [ 'slick', 'redias-testimonials', 'elementor-icons-line-awesome-icons' ];
    }

    public function get_script_depends() {
        return [ 'slick', 'redias-el-script' ];
    }

    /**
     * Register controls
     */
    protected function register_controls() {

        $this->section_general();
        $this->section_testimonials();
        $this->section_controls();
        $this->box_style();
        $this->name_style();
        $this->position_style();
        $this->content_style();
        $this->quote_icon_style();
        $this->style_navigation();
        $this->style_pagination();

    }

    /**
	 * General Controls
	 *
	 * @return void
	 */
	protected function section_general() {

		$this->start_controls_section(
			'section_general',
			[
				'label' => esc_html__( 'General', 'redias-core' )
			]
		);

		$this->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Layout', 'Text-domain' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1'  => esc_html__( 'Style 1', 'Text-domain' ),
                    '2'  => esc_html__( 'Style 2', 'Text-domain' ),
                ],
                'default' => '1'
            ]
        );

		$this->add_control(
			'carousel',
			[
				'label'        => esc_html__( 'Carousel', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'frontend_available' => true,
				'render_type' => 'ui',
			]
		);

		$this->add_responsive_control(
			'wrapper_padding',
			[
				'label' => esc_html__( 'Padding', 'textdomain' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .navi-top-right .slick-slider' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition'    => [
                    'carousel'    => 'yes',
					'navigation' => ['arrow', 'both'],
					'nav_style' => 'top-right'
                ],
			]
		);

		$this->add_responsive_control(
			'dl_column',
			[
				'label' => esc_html__( 'Column', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => 0,
                        'max' => 4,
                        'step' => 1,
                    ],
				],
                'default' => [
					'size' => 3,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 2,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 1,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .el-testi-items' => 'grid-template-columns: repeat({{SIZE}},1fr);',
                ],
                'condition'    => [
                    'carousel!'    => 'yes',
                ],
			]
		);

        $this->add_responsive_control(
			'grid_gap',
			[
				'label' => esc_html__( 'Grid Gap', 'redias-core' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 150
					],
				],
				'default'    => [
					'unit' => 'px',
					'size' => 30
				],
				'selectors' => [
					'{{WRAPPER}} .el-testi-items' => 'grid-gap: {{SIZE}}{{UNIT}};',
                ],
                'condition'    => [
					'carousel!'    => 'yes',
                ],
			]
		);

        $this->end_controls_section();

	}

    /**
     * Testimonials
     *
     * @return void
     */
    protected function section_testimonials() {

        $this->start_controls_section(
            'section_testimonials',
            [
                'label' => esc_html__( 'Testimonials', 'redias-core' ),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'image',
            [
                'label'   => esc_html__( 'Image Thumb', 'redias-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'name',
            [
                'label'       => esc_html__( 'Name', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Jonathan Smith', 'redias-core' ),
                'placeholder' => esc_html__( 'Name...', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'position',
            [
                'label'       => esc_html__( 'Position', 'redias-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Manager', 'redias-core' ),
                'placeholder' => esc_html__( 'Position...', 'redias-core' ),
            ]
        );

        $repeater->add_control(
            'content',
            [
                'label'       => esc_html__( 'Content', 'redias-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'rows'        => 5,
                'default'     => '',
                'placeholder' => esc_html__( 'Content...', 'redias-core' ),
            ]
        );

        $this->add_control(
            'testimonial_items',
            [
                'label'   => esc_html__( 'Testimonials', 'redias-core' ),
                'type'    => Controls_Manager::REPEATER,
                'fields'  => $repeater->get_controls(),
                'title_field'  => '{{{ name }}}',
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' =>  esc_html__( 'Eredrik Johanson', 'redias-core' ),
                        'position' =>  esc_html__( 'Financial .INC', 'redias-core' ),
                        'content' =>  esc_html__( 'Redias a trusted for providing assistants. Initially their main objective was to ensure service they provide these people are loyal to their industry. ', 'redias-core' ),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' =>  esc_html__( 'Félix Lengyel', 'redias-core' ),
                        'position' =>  esc_html__( 'Corporate .INC', 'redias-core' ),
                        'content' =>  esc_html__( 'Redias a trusted for providing assistants. Initially their main objective was to ensure service they provide these people are loyal to their industry. ', 'redias-core' ),
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' =>  esc_html__( 'Brandon Larned', 'redias-core' ),
                        'position' =>  esc_html__( 'Marketing .INC', 'redias-core' ),
                        'content' =>  esc_html__( 'Redias a trusted for providing assistants. Initially their main objective was to ensure service they provide these people are loyal to their industry.', 'redias-core' ),
                    ],
                ],
            ]
        );

		$this->end_controls_section();

    }

    /**
	 * Carousel Controls
	 *
	 * @return void
	 */
	protected function section_controls() {

		$this->start_controls_section(
			'section_carousel_settings',
			[
				'label' => esc_html__( 'Carousel Settings', 'redias-core' ),
				'condition'    => [
					'carousel'    => 'yes'
				],
			]
		);

		$slides_per_show = range( 1, 10 );
		$slides_per_show = array_combine( $slides_per_show, $slides_per_show );

		$this->add_responsive_control(
			'slides_per_show',
			[
				'label' => esc_html__( 'Slides to Show', 'elementor' ),
				'type' => Controls_Manager::SELECT,
				'default' => 3,
				'tablet_default' => 2,
				'mobile_default' => 1,
				'options' => $slides_per_show,
				'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel'    => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'slides_per_scroll',
			[
				'label' => esc_html__( 'Slides to Scroll', 'elementor' ),
				'type' => Controls_Manager::SELECT,
				'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'elementor' ),
				'default' => 1,
				'tablet_default' => 1,
				'mobile_default' => 1,
				'options' => $slides_per_show,
				'condition' => [
					'carousel'    => 'yes'
				],
				'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

        $this->add_responsive_control(
			'spaceBetween',
			[
				'label'      => esc_html__( 'Space Between', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', 'em'],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 150,
						'step' => 1
					],
					'em'  => [
						'min' => 0,
						'max' => 100
					],
				],
                'default' => [
					'unit' => 'px',
					'size' => 12.5
				],
                'tablet_default' => [
					'unit' => 'px',
					'size' => 12.5
				],
                'mobile_default' => [
					'unit' => 'px',
					'size' => 0
				],
				'selectors'  => [
					'{{WRAPPER}} .slick-list' => 'margin: 0 -{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .slick-slide' => 'margin: 0 {{SIZE}}{{UNIT}};'
				],
				'condition'    => [
					'carousel'    => 'yes',
				],
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'        => esc_html__( 'Autoplay', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel'    => 'yes',
				],
			]
		);

		$this->add_control(
			'autoplay_speed',
			[
				'label'   => esc_html__( 'Autoplay Speed', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 500,
				'max'     => 20000,
				'step'    => 5,
				'default' => 5000,
				'condition' => [
					'carousel' => 'yes',
					'autoplay' => 'yes'
                ],
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'pause_on_hover',
			[
				'label'        => esc_html__( 'Pause on Hover', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'condition' => [
					'carousel' => 'yes',
					'autoplay' => 'yes'
				],
                'frontend_available' => true,
				'render_type' => 'ui'
			]
		);

		$this->add_control(
			'infinite_loop',
			[
				'label'        => esc_html__( 'Infinite Loop', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel'    => 'yes'
				],
			]
		);

		$this->add_control(
			'anim_speed',
			[
				'label'   => esc_html__( 'Animation Speed', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 100,
				'max'     => 3000,
				'step'    => 5,
				'default' => 500,
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel'    => 'yes'
				],
			]
		);

        $this->add_control(
			'center_mode',
			[
				'label'        => esc_html__( 'Center Mode', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'redias-core' ),
				'label_off'    => esc_html__( 'No', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'no',
                'frontend_available' => true,
				'render_type' => 'ui',
				'condition'    => [
					'carousel'    => 'yes'
				],
			]
		);

        $this->add_responsive_control(
			'center_padding',
			[
				'label'   => esc_html__( 'Center Padding', 'redias-core' ),
				'type'    => Controls_Manager::NUMBER,
				'min'     => 0,
				'max'     => 200,
				'step'    => 1,
				'default' => 50,
				'tablet_default' => 30,
				'mobile_default' => 10,
                'frontend_available' => true,
				'render_type' => 'ui',
                'condition' => [
					'carousel'    => 'yes',
					'center_mode' => 'yes'
				],
			]
		);

		$this->add_control(
			'navigation',
			[
				'label' => esc_html__( 'Navigation', 'redias-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'None', 'redias-core' ),
					'arrow' => esc_html__( 'Arrow', 'redias-core' ),
					'dots' => esc_html__( 'Dots', 'redias-core' ),
					'both' => esc_html__( 'Arrow & Dots', 'redias-core' ),
				],
				'default' => 'none',
				'frontend_available' => true,
				'style_transfer' => true,
				'condition'    => [
					'carousel'    => 'yes'
				],
			]
		);

        $this->add_control(
			'arrow_prev_icon',
			[
				'label' => esc_html__( 'Previous Icon', 'redias-core' ),
				'label_block' => false,
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-left',
					'library' => 'elementor-icons-line-awesome-icons',
				],
				'condition' => [
					'carousel'    => 'yes',
					'navigation' => ['arrow', 'both']
				],
			]
		);

		$this->add_control(
			'arrow_next_icon',
			[
				'label' => esc_html__( 'Next Icon', 'redias-core' ),
				'label_block' => false,
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-long-arrow-alt-right',
					'library' => 'elementor-icons-line-awesome-icons',
				],
				'condition' => [
					'carousel'    => 'yes',
					'navigation' => ['arrow', 'both']
				],
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Box Style
	 *
	 * @return void
	 */
	protected function box_style() {

		$this->start_controls_section(
			'box_style_section',
			[
				'label' => esc_html__( 'Box', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'box_background',
				'label'    => esc_html__( 'Background', 'redias-core' ),
				'types'    => ['classic', 'gradient'],
				'exclude'  => ['image'],
				'selector' => '{{WRAPPER}} .el-testimonial-item',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'box_border',
				'label'    => esc_html__( 'Border', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-testimonial-item',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name'     => 'testi_box_shadow',
				'selector' => '{{WRAPPER}} .el-testimonial-item',
			]
		);

		$this->add_responsive_control(
			'box_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-testimonial-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'box_padding',
			[
				'label'      => esc_html__( 'Padding', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-testimonial-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->end_controls_section();

	}

	/**
	 * Name Style
	 *
	 * @return void
	 */
	protected function name_style() {

		$this->start_controls_section(
			'name_style_section',
			[
				'label' => esc_html__( 'Name', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'name_typography',
				'label'    => esc_html__( 'Typography', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-testimonial-item h3',
			]
		);

		$this->add_control(
			'name_color',
			[
				'label'     => esc_html__( 'Text Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .el-testimonial-item h3' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'name_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-testimonial-item h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->end_controls_section();
		
	}

	/**
	 * Name Style
	 *
	 * @return void
	 */
	protected function position_style() {

		$this->start_controls_section(
			'position_style_section',
			[
				'label' => esc_html__( 'Position', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'position_typography',
				'label'    => esc_html__( 'Typography', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-testimonial-item h4',
			]
		);

		$this->add_control(
			'position_color',
			[
				'label'     => esc_html__( 'Text Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .el-testimonial-item h4' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'position_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-testimonial-item h4' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->end_controls_section();
		
	}

	/**
	 * Name Style
	 *
	 * @return void
	 */
	protected function content_style() {

		$this->start_controls_section(
			'content_style_section',
			[
				'label' => esc_html__( 'Content', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'content_typography',
				'label'    => esc_html__( 'Typography', 'redias-core' ),
				'selector' => '{{WRAPPER}} .el-testimonial-item p',
			]
		);

		$this->add_control(
			'content_color',
			[
				'label'     => esc_html__( 'Text Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .el-testimonial-item p' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'content_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .el-testimonial-item p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->end_controls_section();
		
	}

	/**
	 * Quote Icon Style
	 *
	 * @return void
	 */
	protected function quote_icon_style() {

		$this->start_controls_section(
			'quote_icon_style_section',
			[
				'label' => esc_html__( 'Quote Icon', 'redias-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'quote_icon_visibility',
			[
				'label'        => esc_html__( 'Visibility', 'redias-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Show', 'redias-core' ),
				'label_off'    => esc_html__( 'Hide', 'redias-core' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'quote_icon',
			[
				'label' => esc_html__( 'Quote Icon', 'redias-core' ),
				'label_block' => false,
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
                'exclude_inline_options' => ['svg'],
				'default' => [
					'value' => 'las la-quote-right',
					'library' => 'elementor-icons-line-awesome-icons',
				],
				'condition' => [
					'quote_icon_visibility' => 'yes'
				],
			]
		);

		$this->add_responsive_control(
			'quote_icon_size',
			[
				'label'      => esc_html__( 'Icon Size', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range'      => [
					'px' => [
						'min'  => 5,
						'max'  => 150,
						'step' => 1
					]
				],
				'selectors'  => [
					'{{WRAPPER}} .el-testimonial-item .quote-icon' => 'font-size: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'quote_icon_visibility' => 'yes'
				],
			]
		);

		$this->add_control(
			'quote_icon_color',
			[
				'label'     => esc_html__( 'Icon Color', 'redias-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .el-testimonial-item .quote-icon' => 'color: {{VALUE}}',
				],
				'condition' => [
					'quote_icon_visibility' => 'yes'
				],
			]
		);

		$this->add_responsive_control(
			'quote_icon_x_pos',
			[
				'label'      => esc_html__( 'X Position', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', '%'],
				'range'      => [
					'px' => [
						'min'  => -500,
						'max'  => 500,
						'step' => 5,
					],
					'%'  => [
						'min' => -100,
						'max' => 100,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .layout-1 .quote-icon' => 'right: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'quote_icon_visibility' => 'yes',
					'layout' => '1',
				],
			]
		);

		$this->add_responsive_control(
			'quote_icon_y_pos',
			[
				'label'      => esc_html__( 'Y Position', 'redias-core' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => ['px', '%'],
				'range'      => [
					'px' => [
						'min'  => -500,
						'max'  => 500,
						'step' => 5,
					],
					'%'  => [
						'min' => -100,
						'max' => 100,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .layout-1 .quote-icon' => 'bottom: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'quote_icon_visibility' => 'yes',
					'layout' => '1',
				],
			]
		);

		$this->add_responsive_control(
			'quote_icon_margin',
			[
				'label'      => esc_html__( 'Margin', 'redias-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors'  => [
					'{{WRAPPER}} .layout-2 .quote-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'quote_icon_visibility' => 'yes',
					'layout' => '2',
				],
			]
		);
		
		$this->end_controls_section();
		
	}

    /**
     * Render Content
     *
     * @return void
     */
    protected function render() {

		$settings = $this->get_settings_for_display();

        if( 'yes' === $settings['carousel'] ) {
			$this->caraousel_layout();
		}else{
			$this->grid_layout();
		}
		
    }

	/**
	 * Carousel Layout
	 *
	 * @return void
	 */
	protected function caraousel_layout(){
		$settings = $this->get_settings_for_display();
		$testimonial_items = $settings['testimonial_items'];

        $dots_mobile = 'yes' === $settings['dots_hide_mobile'] ? ' dots-none' : '';
        $nav_mobile = 'yes' === $settings['nav_hide_mobile'] ? ' nav-none' : '';

		if( 'arrow' === $settings['navigation'] || 'both' === $settings['navigation'] ){
			$nav_style = 'top-right' == $settings['nav_style'] ? ' navi-top-right' : '';
		}else{
			$nav_style = '';
		}

		$this->add_render_attribute(
			'carousel_wrapper',
			[ 
				'class' => [ 'dl-carousel', 'layout-' . $settings['layout'] ],
			]
		); ?>
		<div class="el-testimonial-wrapper<?php echo esc_attr( $nav_style ); ?>">
        <?php if ( ! empty( $testimonial_items ) ) : ?>
        <div <?php echo $this->get_render_attribute_string( 'carousel_wrapper' ); ?>>
            <?php 
                foreach ( $testimonial_items as $testimonial_item ):
                if( ! empty( $testimonial_item['content'] ) ) : 
				$client_thumb_url = ! empty( $testimonial_item['image']['url'] ) ? $testimonial_item['image']['url'] : Utils::get_placeholder_image_src();
				?>
                <div class="slick-slide">
                    <div class="el-testimonial-item">
						<?php if( 'yes' === $settings['quote_icon_visibility'] ) : ?>
							<div class="quote-icon"><?php Icons_Manager::render_icon( $settings['quote_icon'], ['aria-hidden' => 'true'] ); ?></div>
						<?php endif; ?>
						<p><?php echo Helper::kses_basic( $testimonial_item['content'] ); ?></p>
						<?php if( ! empty( $testimonial_item['name'] ) ) : ?>
						<div class="el-testi-meta">
							<div class="el-client-thumb">
								<img src="<?php echo esc_url( $client_thumb_url ); ?>" alt="<?php echo esc_attr( $testimonial_item['name'] ); ?>">
							</div>
							<div class="el-client-info">
								<h3><?php echo esc_html( $testimonial_item['name'] ); ?></h3>
								<?php
								if( ! empty( $testimonial_item['position'] ) ) {
									echo '<h4>'. esc_html( $testimonial_item['position'] ) .'</h4>';
								}
								?>
							</div>
						</div>
						<?php endif; ?>
                    </div>
                </div>
                <?php 
                endif;
                endforeach;?>
            <?php
				echo '<div class="carousel-preloader"><div class="dot-flashing"></div></div>';
            ?>
        </div>
        <?php if( 'dots' === $settings['navigation'] || 'both' === $settings['navigation'] ) : ?>
        <div class="dl-carousel-dots<?php echo esc_attr( $dots_mobile ); ?>"></div>
        <?php endif; ?>
		<?php if( 'arrow' === $settings['navigation'] || 'both' === $settings['navigation'] ) : ?>
        <div class="dl-carousel-nav <?php echo esc_attr( 'nav-' . $settings['nav_style'] ) . esc_attr( $nav_mobile ); ?>"></div>
        <?php if ( ! empty( $settings['arrow_prev_icon']['value'] ) ) : ?>
			<button type="button" class="slick-prev nav-hidden"><?php Icons_Manager::render_icon( $settings['arrow_prev_icon'], ['aria-hidden' => 'true'] ); ?></button>
		<?php endif; ?>

		<?php if ( ! empty( $settings['arrow_next_icon']['value'] ) ) : ?>
			<button type="button" class="slick-next nav-hidden"><?php Icons_Manager::render_icon( $settings['arrow_next_icon'], ['aria-hidden' => 'true'] ); ?></button>
		<?php endif; ?>
		<?php endif; ?>
        <?php endif; ?>
		</div>
		<?php
	}

	/**
	 * Grid Layout
	 *
	 * @return void
	 */
	protected function grid_layout() {
		$settings = $this->get_settings_for_display();
		$testimonial_items = $settings['testimonial_items'];

		$this->add_render_attribute(
			'grid_wrapper',
			[ 
				'class' => [ 'el-testi-items', 'layout-' . $settings['layout'] ],
			]
		); ?>
        <?php if ( ! empty( $testimonial_items ) ) : ?>
		<div <?php echo $this->get_render_attribute_string( 'grid_wrapper' ); ?>>
            <?php 
			foreach ( $testimonial_items as $testimonial_item ):
			if( ! empty( $testimonial_item['content'] ) ) : 
			$client_thumb_url = ! empty( $testimonial_item['image']['url'] ) ? $testimonial_item['image']['url'] : Utils::get_placeholder_image_src();
			?>
			<div class="el-testimonial-item">
				<?php if( 'yes' === $settings['quote_icon_visibility'] ) : ?>
					<div class="quote-icon"><?php Icons_Manager::render_icon( $settings['quote_icon'], ['aria-hidden' => 'true'] ); ?></div>
				<?php endif; ?>
				<p><?php echo Helper::kses_basic( $testimonial_item['content'] ); ?></p>
				<?php if( ! empty( $testimonial_item['name'] ) ) : ?>
				<div class="el-testi-meta">
					<div class="el-client-thumb">
						<img src="<?php echo esc_url( $client_thumb_url ); ?>" alt="<?php echo esc_attr( $testimonial_item['name'] ); ?>">
					</div>
					<div class="el-client-info">
						<h3><?php echo esc_html( $testimonial_item['name'] ); ?></h3>
						<?php
						if( ! empty( $testimonial_item['position'] ) ) {
							echo '<h4>'. esc_html( $testimonial_item['position'] ) .'</h4>';
						}
						?>
					</div>
				</div>
				<?php endif; ?>
			</div>
			<?php 
			endif;
			endforeach;?>
        </div>
		<?php
		endif;
	}

}