<?php
/**
 * RECENT Posts Widget
 *
 * @package RediasCore
 */
namespace RediasCore\Widgets;
use \RediasCore\Classes\Helper;

class PostWidget extends \WP_Widget {

	/**
	 * Sets up a new Recent Posts widget instance.
	 *
	 * @since 2.8.0
	 */
	public function __construct() {
		$widget_ops = array(
			'classname'                   => 'redias_recent_entries',
			'description'                 => __( 'Your site&#8217;s most recent Posts.', 'redias' ),
			'customize_selective_refresh' => true,
		);
		parent::__construct( 'redias-recent-posts', __( 'Redias - Recent Posts' ), $widget_ops );
		$this->alt_option_name = 'redias_recent_entries';
	}

	/**
	 * Outputs the content for the current Recent Posts widget instance.
	 *
	 * @since 2.8.0
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Recent Posts widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$default_title = __( 'Recent Posts', 'redias-core' );
		$title         = ( ! empty( $instance['title'] ) ) ? $instance['title'] : $default_title;

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		$length = ( ! empty( $instance['length'] ) ) ? absint( $instance['length'] ) : 40;
		if ( ! $number ) {
			$number = 5;
		}
		if ( ! $length ) {
			$length = 40;
		}
		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;
		$circle = isset( $instance['circle'] ) && $instance['circle'] === true ? 'circle' : 'square';

		$r = new \WP_Query(
			/**
			 * Filters the arguments for the Recent Posts widget.
			 *
			 * @since 3.4.0
			 * @since 4.9.0 Added the `$instance` parameter.
			 *
			 * @see WP_Query::get_posts()
			 *
			 * @param array $args     An array of arguments used to retrieve the recent posts.
			 * @param array $instance Array of settings for the current widget.
			 */
			apply_filters(
				'widget_posts_args',
				array(
					'posts_per_page'      => $number,
					'no_found_rows'       => true,
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
				),
				$instance
			)
		);

		if ( ! $r->have_posts() ) {
			return;
		}
		?>

		<?php echo $args['before_widget']; ?>

		<?php
		if ( $title ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		$format = current_theme_supports( 'html5', 'navigation-widgets' ) ? 'html5' : 'xhtml';

		/** This filter is documented in wp-includes/widgets/class-wp-nav-menu-widget.php */
		$format = apply_filters( 'navigation_widgets_format', $format );

		if ( 'html5' === $format ) {
			// The title may be filtered: Strip out HTML and make sure the aria-label is never empty.
			$title      = trim( strip_tags( $title ) );
			$aria_label = $title ? $title : $default_title;
			echo '<nav role="navigation" aria-label="' . esc_attr( $aria_label ) . '">';
		}
		?>

		<ul class="widget-posts-list <?php echo esc_attr( $circle ); ?>">
			<?php foreach ( $r->posts as $recent_post ) : ?>
				<?php
				$post_title   = get_the_title( $recent_post->ID );
				$title        = ( ! empty( $post_title ) ) ? $post_title : __( '(no title)' );
				$aria_current = '';

				if ( get_queried_object_id() === $recent_post->ID ) {
					$aria_current = ' aria-current="page"';
				}
				?>
				<li>
                
                    <div class="widget-post-thumb">
							<a href="<?php the_permalink( $recent_post->ID ); ?>"<?php echo $aria_current; ?>>
							<?php 
								if( has_post_thumbnail( $recent_post->ID ) ) {
									$image_attributes = wp_get_attachment_image_src( get_post_thumbnail_id( $recent_post->ID ), 'redias_120x120' );
									$img_url = isset($image_attributes[0]) ? $image_attributes[0] : '';
									if( $img_url ) {
										echo '<div class="thumb" style="background-image: url('. esc_url( $image_attributes[0] ) .');"></div>';
									}else{
										echo '<div class="thumb" style="background-image: url('. REDIASCORE_URL.'/assets/img/no_img_thumb.jpg' .');"></div>';
									}
								}else{
									echo '<div class="thumb" style="background-image: url('. REDIASCORE_URL.'/assets/img/no_img_thumb.jpg' .');"></div>';	
								}
							?>
							</a>
                    </div>
                
                    <div class="widget-post-content">
                        <div class="widget-post-content-inner">
                            <a href="<?php the_permalink( $recent_post->ID ); ?>"<?php echo $aria_current; ?>><?php echo Helper::limit_latter($title, esc_attr( $length )); ?></a>
                            <?php if ( $show_date ) : ?>
                                <span class="post-date"><?php echo get_the_date( '', $recent_post->ID ); ?></span>
                            <?php endif; ?>
                        </div>
                    </div>
					
				</li>
			<?php endforeach; ?>
		</ul>

		<?php
		if ( 'html5' === $format ) {
			echo '</nav>';
		}

		echo $args['after_widget'];
	}

	/**
	 * Handles updating the settings for the current Recent Posts widget instance.
	 *
	 * @since 2.8.0
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance              = $old_instance;
		$instance['title']     = sanitize_text_field( $new_instance['title'] );
		$instance['number']    = (int) $new_instance['number'];
		$instance['length']    = (int) $new_instance['length'];
		$instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;
		$instance['circle'] = isset( $new_instance['circle'] ) ? (bool) $new_instance['circle'] : false;
		return $instance;
	}

	/**
	 * Outputs the settings form for the Recent Posts widget.
	 *
	 * @since 2.8.0
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$length    = isset( $instance['length'] ) ? absint( $instance['length'] ) : 30;
		$show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
		$circle = isset( $instance['circle'] ) ? (bool) $instance['circle'] : false;
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'length' ); ?>"><?php _e( 'Title Length:' ); ?></label>
			<input class="tiny-text" id="<?php echo $this->get_field_id( 'length' ); ?>" name="<?php echo $this->get_field_name( 'length' ); ?>" type="number" step="1" min="1" value="<?php echo $length; ?>" size="3" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:' ); ?></label>
			<input class="tiny-text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="1" value="<?php echo $number; ?>" size="3" />
		</p>

		<p>
			<input class="checkbox" type="checkbox"<?php checked( $show_date ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><?php _e( 'Display post date?' ); ?></label>
		</p>

		<p>
			<input class="checkbox" type="checkbox"<?php checked( $circle ); ?> id="<?php echo $this->get_field_id( 'circle' ); ?>" name="<?php echo $this->get_field_name( 'circle' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'circle' ); ?>"><?php _e( 'Enable circle thumbnails?' ); ?></label>
		</p>
		<?php
	}
}