<?php
/**
 * Helper Class
 *
 * @package Redias
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}
class RediasHelper {

    /**
     * Get a list of all the allowed html tags.
     *
     * @param string $level Allowed levels are basic and intermediate
     * @return array
     */
    static function get_allowed_html_tags( $level = 'basic' ) {
        $allowed_html = [
            'b'      => [],
            'i'      => [],
            'u'      => [],
            's'      => [],
            'br'     => [],
            'em'     => [],
            'del'    => [],
            'ins'    => [],
            'sub'    => [],
            'sup'    => [],
            'code'   => [],
            'mark'   => [],
            'small'  => [],
            'strike' => [],
            'abbr'   => [
                'title' => [],
            ],
            'span'   => [
                'class' => [],
            ],
            'strong' => [],
            'a'       => [
                'href'  => [],
                'title' => [],
                'class' => [],
                'id'    => [],
            ],
        ];

        if ( $level === 'intermediate' ) {
            $tags = [
                'a'       => [
                    'href'  => [],
                    'target'  => [],
                    'title' => [],
                    'class' => [],
                    'id'    => [],
                ],
                'q'       => [
                    'cite' => [],
                ],
                'img'     => [
                    'src'    => [],
                    'alt'    => [],
                    'height' => [],
                    'width'  => [],
                ],
                'iframe' => [
                    'title' => [],
                    'width' => [],
                    'height' => [],
                    'src' => [],
                    'frameborder' => [],
                    'allow' => [],
                    'allowfullscreen' => [],

                ],
                'dfn'     => [
                    'title' => [],
                ],
                'time'    => [
                    'datetime' => [],
                ],
                'cite'    => [
                    'title' => [],
                ],
                'acronym' => [
                    'title' => [],
                ],
                'hr'      => [],
                'svg'     => [
                    'class'           => true,
                    'aria-hidden'     => true,
                    'aria-labelledby' => true,
                    'role'            => true,
                    'xmlns'           => true,
                    'width'           => true,
                    'height'          => true,
                    'viewbox'         => true,
                ],
                'g'       => ['fill' => true],
                'title'   => ['title' => true],
                'path'    => [
                    'd'    => true,
                    'fill' => true,
                ],
            ];

            $allowed_html = array_merge( $allowed_html, $tags );
        }

        return $allowed_html;
    }

    /**
     * Strip all the tags except allowed html tags
     *
     * Basic tags
     * 
     * @param string $string
     * @return string
     */
    static function kses_basic( $string = '' ) {
        return wp_kses( $string, self::get_allowed_html_tags( 'basic' ) );
    }

    /**
     * Strip all the tags except allowed html tags
     *
     * Advanced tags
     *
     * @param string $string
     * @return string
     */
    static function kses_advance( $string = '' ) {
        return wp_kses( $string, self::get_allowed_html_tags( 'intermediate' ) );
    }

    /**
     * Limit Letter
     *
     * @param [type] $string
     * @param [type] $limit_length
     * @param string $suffix
     * @return void
     */
    static function limit_latter( $string, $limit_length, $suffix = '...' ) {
        if ( strlen( $string  ?? '' ) > $limit_length ) {
            return strip_shortcodes( substr( $string, 0, $limit_length ) . $suffix );
        } else {
            return strip_shortcodes( esc_html( $string ) );
        }
    }

    /**
     * Get Taxonomy Terms
     *
     * @param string $taxonomy
     * @param integer $count
     * @param boolean $link
     * @param string $class
     * @return void
     */
    static function get_terms( $taxonomy="category", $count=1, $link=true, $class="dl-cat-item", $div=true, $post_id = '' ) {
		$postid = ! empty( $post_id ) ? $post_id : get_the_id();
        $dl_terms = get_the_terms( $postid, $taxonomy );
		$dl_max_cat = $count;
		if( $dl_terms ) {
            if( $div === true ) {
                echo '<div class="dl-cat-items">';
            }
			foreach ( $dl_terms as $dl_term ) {
				$dl_cat = get_category( $dl_term );
				if( $link ) {
					printf( 
                        '<a href="%1$s" class="'. $class .'">%2$s</a>',
                        esc_url( get_category_link( $dl_cat->term_id ) ),
                        esc_html( $dl_cat->name )
                    );
				}else{
					printf( '<span>%1$s</span>', esc_html( $dl_cat->name ) );
				}
				
				$dl_max_cat--;

				if ( 0 == $dl_max_cat ) {
					break;
				}
			}
            if( $div === true ) {
                echo '</div>';
            }
		}
	}

    /**
     * Get Featured Image
     *
     * @param string $size
     * @return void
     */
    static function get_featured_image_url( $size = 'full', $post_id = '' ) {
        if( ! empty( $post_id ) ) {
            $postid = $post_id;
        }else{
            global $wp_query;
            $postid = $wp_query->post->ID;
        }
        $image_array = wp_get_attachment_image_src( get_post_thumbnail_id( $postid ), $size );
        $image_url = ! empty( $image_array[0] ) ? $image_array[0] : '';
        return $image_url;
    }

    /**
     * @uses WP_Query
     * @uses get_queried_object()
     * @see get_the_ID()
     * @return int
     */
    static function get_the_post_id() {
        if ( in_the_loop() ) {
            $post_id = get_the_ID();
        } else {
            global $wp_query;
            $post_id = $wp_query->get_queried_object_id();
        }
        return $post_id;
    }

    /**
     * Get ACF Field Value
     *
     * @param [type] $v
     * @return [string, array, object]
     */
    static function get_field( $v ) {
        if ( function_exists( 'get_field' ) ) {
            $value = get_field( $v, self::get_the_post_id() );
        } else {
            $value = '';
        }
        return $value;
    }

    /**
     * Get ACF Field Value from post ID
     *
     * @param [type] $v
     * @param string $postid
     * @return string|array|object|integer
     */
    static function get_field_by_id( $v, $postid = '' ) {
        $post_id = ! empty( $postid ) ? $postid : self::get_the_post_id();
        if ( function_exists( 'get_field' ) ) {
            $value = get_field( $v, $post_id );
        } else {
            $value = '';
        }
        return $value;
    }

    /**
     * Get ACF Option Value
     *
     * @param [type] $v
     * @param string $default
     * @return void
     */
    static function get_option_field( $v, $default = '' ) {
        if ( function_exists( 'get_field' ) ) {
            $value = '' != get_field( $v, 'option' ) ? get_field( $v, 'option' ) : $default;
        } else {
            $value = '';
        }
        return $value;
    }

    /**
     * Get ACF Meta Field Value
     *
     * @param [type] $key
     * @param string $default
     * @return void
     */
    static function get_meta_field( $key, $default = '' ) {
        $output = '';
        if( ! empty( $key ) ) {
            $output = null != self::get_field( $key ) ? self::get_field( $key ) : self::kses_basic( $default );
        }
        return $output;
    }

    /**
     * Get ACF Taxo Meta Field Value
     *
     * @param [type] $key
     * @param [type] $term
     * @param string $default
     * @return void
     */
    static function get_taxo_field( $key, $term, $default = '' ) {
        $output = '';
        if ( function_exists( 'get_field' ) ) {
            if( ! empty( $key && $term ) ) {
                $output = ! empty( get_field( $key, $term ) ) ? get_field( $key, $term ) : self::kses_basic( $default );
            }
        }
        return $output;
    }

    /**
     * Get the title
     *
     * @return void
     */
    static function get_title() {
        if( class_exists('WooCommerce') ) {
            if ( is_shop() ) {
                echo ! empty( redias_get_option( 'shop_title' ) ) ? esc_html( redias_get_option( 'shop_title' ) ) : esc_html__( 'Shop', 'redias' );
            } elseif ( is_home() ) {
                $blog_title = redias_get_option( 'blog_pb_title', esc_html__( 'Latest Blog Posts', 'redias' ) );
                return $blog_title;
            } elseif ( is_page() || is_single() ) {
                return get_the_title( self::get_the_post_id() );
            } elseif ( is_category() ) {
                return single_cat_title( '', false );
            } elseif ( is_archive() && ! is_author() ) {
                return get_the_archive_title();
            } elseif ( is_search() ) {
                return esc_html__( 'Search for: “', 'redias' ) . get_search_query() . '”';
            } elseif ( is_author() ) {
                return esc_html__( 'All Posts by: ', 'redias' ) . get_the_author_meta('display_name');
            } else {
                return get_the_title( self::get_the_post_id() );
            }
        }else{
            if ( is_home() ) {
                $blog_title = redias_get_option( 'blog_pb_title', esc_html__( 'Latest Blog Posts', 'redias' ) );
                return $blog_title;
            } elseif ( is_page() || is_single() ) {
                return get_the_title( self::get_the_post_id() );
            } elseif ( is_category() ) {
                return single_cat_title( '', false );
            } elseif ( is_archive() && ! is_author() ) {
                return get_the_archive_title();
            } elseif ( is_search() ) {
                return esc_html__( 'Search for: “', 'redias' ) . get_search_query() . '”';
            } elseif ( is_author() ) {
                return esc_html__( 'All Posts by: ', 'redias' ) . get_the_author_meta('display_name');
            } else {
                return get_the_title( self::get_the_post_id() );
            }
        }
    }

    /**
     * Get Breadcrumb
     *
     * @return void
     */
    static function get_breadcrumb() {
        $home_text = esc_html__( 'Home', 'redias' );
        ?>
        <ol class="breadcrumb-wrap">
            <li><a href="<?php echo esc_url( home_url( '/' ) ) ?>"><?php echo esc_html( $home_text ); ?></a><span class="sep"></span></li>
            <?php if( is_singular('redias-projects') && self::has_terms('redias-project-cat') === true ) : ?>	
                <li><?php self::get_terms( 'redias-project-cat', 1, true, '', false ); ?><span class="sep"></span></li>
            <?php elseif( is_singular('post') && self::has_terms('category') === true ) : ?>
                <li><?php self::get_terms( 'category', 1, true, '', false ); ?><span class="sep"></span></li>
            <?php endif; ?>
            <?php if( ( class_exists('WooCommerce') && is_woocommerce() ) && ! is_shop() ) : ?>
                <li><a href="<?php echo esc_url( wc_get_page_permalink( 'shop' ) ); ?>"><?php esc_html_e( 'Shop', 'redias' ); ?></a><span class="sep"></span></li>
            <?php endif; ?>
            <?php
            if ( is_home() ) :
                $page_id = get_option( 'page_for_posts' );
                if( 0 != $page_id ){
                    echo '<li class="active"> '. self::limit_latter( get_the_title( esc_attr( $page_id ) ), 30, '...' ) .'</li>';
                }else{
                    echo '<li class="active"> '. self::limit_latter( esc_html__( 'News and Insights', 'redias' ), 30, '...' )  .'</li>';
                } ?>
            <?php else: 
                $limit_letter = is_search() ? 50 : 30; ?>
                <li class="active"><?php echo self::limit_latter( self::get_title(), $limit_letter, '...' ); ?> </li>
            <?php endif; ?>
        </ol>
        <?php
    }

    /**
     * Theme Layout
     *
     * @return void
     */
    static function theme_layout() {
        $layout = redias_get_option( 'layout_width', 'container' );
        echo esc_attr( $layout );
    }

    /**
     * Get Retina Logo
     *
     * @param [type] $id
     * @return void
     */
    static function get_retina_logo( $id ) {
        $logo_id = get_theme_mod( $id );
        $logo_srcset = '';
        if( ! empty( $logo_id ) ) {
            $logo_url = wp_get_attachment_url( $logo_id );
            $logo_srcset .= 'srcset="'. esc_url( $logo_url ) .' 2x"';
        }
        return $logo_srcset;
    }

    /**
     * Social Profiles
     *
     * @param [type] $data
     * @param string $class
     * @return void
     */
    static function get_social_profiles( $data, $class = 'social-profiles' ) {
        $output = '';
        if( $data ){
            $output .= '<ul class="'. $class .'">';
            foreach ( $data as $item ) {
                if( 'dl-whatsapp' === $item['media'] ) {
                    if( ! empty( $item['whatsapp'] ) ) {
                        $output .= '<li><a href="https://wa.me/'. esc_attr( $item['whatsapp'] ) .'" class="'. esc_attr( str_replace('dl-', '', $item['media'] ) ) .'" target="_blank"><i class="dl '. esc_attr( $item['media'] ) .'"></i></a></li>';
                    }
                }elseif( 'dl-envelope' === $item['media'] ) {
                    if( ! empty( $item['email'] ) ) {
                        $output .= '<li><a href="mailto:'. esc_attr( $item['email'] ) .'" class="'. esc_attr( str_replace('dl-', '', $item['media'] ) ) .'"><i class="dl '. esc_attr( $item['media'] ) .'"></i></a></li>';
                    }
                }else{
                    if( ! empty( $item['media_link'] ) ) {
                        $output .= '<li><a href="'. esc_url( $item['media_link'] ) .'" class="'. esc_attr( str_replace('dl-', '', $item['media'] ) ) .'" target="_blank"><i class="dl '. esc_attr( $item['media'] ) .'"></i></a></li>';
                    }
                }
            }
            $output .= '</ul>';
        }
        return $output;
    }

    /**
     * Mid Header Content
     *
     * @param string $icon
     * @param string $title
     * @param string $content
     * @return void
     */
    static function mid_header_content( $icon = '', $title = '', $content = '' ) {
        if( ! empty( $icon || $title || $content ) ) {
            ?>
            <div class="header-info-item">
                <?php if( ! empty( $icon ) ) : ?>
                <div class="icon">
                    <i class="<?php echo esc_attr( $icon ); ?>"></i>
                </div>
                <?php endif;
                if( ! empty( $title || $content ) ) : ?>
                <div class="info-content">
                    <?php 
                    if( ! empty( $title ) ) {
                        echo '<span>'. self::kses_advance($title) .'</span>';
                    }
                    if( ! empty( $content ) ) {
                        echo self::kses_advance($content);
                    }
                    ?>
                </div>
                <?php endif; ?>
            </div>
            <?php
        }
    }

    /**
     * Get Value
     *
     * @param string $key
     * @return void
     */
    static function get_value( $key = '' ) {
        $content = redias_get_option('mid_header');
        return self::key_exists( $key, $content );
    }

    /**
     * Array Key Exists check
     *
     * @param string $key
     * @param array $array
     * @return void
     */
    static function key_exists( $key = '', $array = [] ) {

        if( is_array($array) ){
            if ( array_key_exists( $key, $array ) ) {
                return $array[$key];
            } else {
                return '';
            }
        }else{
            return '';
        }
        
    }

    /**
     * Get Sticky Logo URL
     *
     * @return string
     */
    static function get_sticky_logo_url() {
        $site_logo = get_theme_mod('custom_logo');
        $site_logo_url = ! empty( $site_logo ) ? wp_get_attachment_url( $site_logo ) : '';
        $sticky_logo = get_theme_mod('redias_sticky_logo');
        $sticky_logo_url = ! empty( $sticky_logo ) ? wp_get_attachment_url( $sticky_logo ) : '';
        $custom_logo = RediasHelper::get_meta_field('redias_custom_sticky_logo');
        $fallback_logo = get_template_directory_uri() .'/assets/img/logo.png';
        if( is_page() && ! empty( $custom_logo ) ) {
            return $custom_logo;
        }else{
            if( ! empty( $sticky_logo_url ) ) {
                return $sticky_logo_url;
            }else{
                return '' != $site_logo_url ? $site_logo_url : $fallback_logo;
            }
        }
    }

    /**
     * Post loop by ID
     *
     * @param [type] $id
     * @param string $post_type
     * @return void
     */
    static function loop_by_id( $id = null, $post_type = 'post' ) {
		$args = array(
			'p' => $id,
			'post_type' => $post_type
		);
		$q = new WP_Query( $args );

		if( $q->have_posts() ) : 

		while ( $q->have_posts() ) : $q->the_post(); 

			the_content();

		endwhile;

		endif; 
	}

    /**
     * Has terms check
     *
     * @param string $taxo
     * @return boolean
     */
    static function has_terms( $taxo = 'category' ) {
		$terms = get_the_terms( get_the_id(), $taxo );
		if( ! empty( $terms ) ) {
			return true;
		}else{
			return false;
		}
	}

    /**
     * Active Footer Widgets
     *
     * @return array
     */
    static function active_footer_widgets() {
        $widgets = [];
        if( is_active_sidebar('footer-1') ) {
            $widgets[] = 'footer-1';
        }
        if( is_active_sidebar('footer-2') ) {
            $widgets[] = 'footer-2';
        }
        if( is_active_sidebar('footer-3') ) {
            $widgets[] = 'footer-3';
        }
        if( is_active_sidebar('footer-4') ) {
            $widgets[] = 'footer-4';
        }
        return $widgets;
    }

    /**
     * Get Footer Top Items
     *
     * @return array
     */
    static function get_footer_top_items() {
        $content = redias_get_option('footer-content');
        return self::key_exists( 'footer-top-items', $content );
    }

    /**
     * Not WooCommerce Pages
     *
     * @return void
     */
    static function not_woocommerce_pages() {
        if( class_exists('WooCommerce') ) {
            if( ! ( is_cart() || is_checkout() || is_account_page() ) ) {
                return true;
            }else{
                return false;
            }
        }else{
            return true;
        }
    }

    /**
     * Get Published Post Count
     *
     * @param string $post_type
     * @return void
     */
    static function get_post_count( $post_type = 'post' ) {
        $count = wp_count_posts($post_type);
        return $count->publish;
    }

    /**
     * Highlighted text
     *
     * @param [type] $text
     * @return string
     */
    static function get_highlighted_text( $text ) {
		return str_replace( array( '{{', '}}' ), array( '<span>', '</span>' ), $text );
	}

    /**
     * Check is elementor page
     */
    static function check_is_elementor(){
        global $post;
        return \Elementor\Plugin::$instance->documents->get( $post->ID )->is_built_with_elementor();
    }

    /**
     * Get file fromat from url
     *
     * @param string $url
     * @return string
     */
    static function get_file_format_from_url( $url = '' ){
        if( ! empty( $url ) ) {
            $headers = get_headers($url, 1);
            if( array_key_exists('Content-Type',$headers) ) {
                $content_type = $headers['Content-Type'];
                return $content_type;
            }else{
                return '';
            }
        }else{
            return '';
        }
    }

    /**
     * Get the excerpt
     *
     * @param [type] $post_id
     * @param integer $limit_length
     * @param string $prefix
     * @return string
     */
    static function get_the_excerpt($post_id = '', $limit_length = 18, $prefix = '...'){
        $post_ID = ! empty( $post_id ) ? $post_id : get_the_ID();
        $excerpt = get_the_excerpt($post_ID);
        $trim_words = wp_trim_words($excerpt, $limit_length, $prefix );
        return $trim_words;
    }

    /**
     * Get All Sidebars
     * @return array
     */
    static function get_sidebars() {
        global $wp_registered_sidebars;
        $array = [
            'default' => esc_html__('Default', 'redias')
        ];
        if ( empty( $wp_registered_sidebars ) )
        return $array;
        foreach ( $wp_registered_sidebars as $sidebar ){
            $array[$sidebar['id']] = $sidebar['name'];
        }

        return $array;
    }
}